import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../common";
export declare namespace KlerosCoreBase {
    type RoundStruct = {
        disputeKitID: BigNumberish;
        pnkAtStakePerJuror: BigNumberish;
        totalFeesForJurors: BigNumberish;
        nbVotes: BigNumberish;
        repartitions: BigNumberish;
        pnkPenalties: BigNumberish;
        drawnJurors: string[];
        sumFeeRewardPaid: BigNumberish;
        sumPnkRewardPaid: BigNumberish;
        feeToken: string;
        drawIterations: BigNumberish;
    };
    type RoundStructOutput = [
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        string[],
        BigNumber,
        BigNumber,
        string,
        BigNumber
    ] & {
        disputeKitID: BigNumber;
        pnkAtStakePerJuror: BigNumber;
        totalFeesForJurors: BigNumber;
        nbVotes: BigNumber;
        repartitions: BigNumber;
        pnkPenalties: BigNumber;
        drawnJurors: string[];
        sumFeeRewardPaid: BigNumber;
        sumPnkRewardPaid: BigNumber;
        feeToken: string;
        drawIterations: BigNumber;
    };
}
export interface KlerosCoreInterface extends utils.Interface {
    functions: {
        "addNewDisputeKit(address)": FunctionFragment;
        "appeal(uint256,uint256,bytes)": FunctionFragment;
        "appealCost(uint256)": FunctionFragment;
        "appealPeriod(uint256)": FunctionFragment;
        "arbitrationCost(bytes,address)": FunctionFragment;
        "arbitrationCost(bytes)": FunctionFragment;
        "changeAcceptedFeeTokens(address,bool)": FunctionFragment;
        "changeCourtParameters(uint96,bool,uint256,uint256,uint256,uint256,uint256[4])": FunctionFragment;
        "changeCurrencyRates(address,uint64,uint8)": FunctionFragment;
        "changeGovernor(address)": FunctionFragment;
        "changeGuardian(address)": FunctionFragment;
        "changeJurorProsecutionModule(address)": FunctionFragment;
        "changePinakion(address)": FunctionFragment;
        "changeSortitionModule(address)": FunctionFragment;
        "convertEthToTokenAmount(address,uint256)": FunctionFragment;
        "courts(uint256)": FunctionFragment;
        "createCourt(uint96,bool,uint256,uint256,uint256,uint256,uint256[4],bytes,uint256[])": FunctionFragment;
        "createDispute(uint256,bytes)": FunctionFragment;
        "createDispute(uint256,bytes,address,uint256)": FunctionFragment;
        "currencyRates(address)": FunctionFragment;
        "currentRuling(uint256)": FunctionFragment;
        "disputeKits(uint256)": FunctionFragment;
        "disputes(uint256)": FunctionFragment;
        "draw(uint256,uint256)": FunctionFragment;
        "enableDisputeKits(uint96,uint256[],bool)": FunctionFragment;
        "execute(uint256,uint256,uint256)": FunctionFragment;
        "executeGovernorProposal(address,uint256,bytes)": FunctionFragment;
        "executeRuling(uint256)": FunctionFragment;
        "getDisputeKitsLength()": FunctionFragment;
        "getNumberOfRounds(uint256)": FunctionFragment;
        "getNumberOfVotes(uint256)": FunctionFragment;
        "getRoundInfo(uint256,uint256)": FunctionFragment;
        "getTimesPerPeriod(uint96)": FunctionFragment;
        "governor()": FunctionFragment;
        "guardian()": FunctionFragment;
        "initialize(address,address,address,address,address,bool,uint256[4],uint256[4],bytes,address)": FunctionFragment;
        "isDisputeKitJumping(uint256)": FunctionFragment;
        "isSupported(uint96,uint256)": FunctionFragment;
        "jurorProsecutionModule()": FunctionFragment;
        "passPeriod(uint256)": FunctionFragment;
        "pause()": FunctionFragment;
        "paused()": FunctionFragment;
        "pinakion()": FunctionFragment;
        "proxiableUUID()": FunctionFragment;
        "setStake(uint96,uint256)": FunctionFragment;
        "setStakeBySortitionModule(address,uint96,uint256,bool)": FunctionFragment;
        "sortitionModule()": FunctionFragment;
        "unpause()": FunctionFragment;
        "upgradeToAndCall(address,bytes)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "addNewDisputeKit" | "appeal" | "appealCost" | "appealPeriod" | "arbitrationCost(bytes,address)" | "arbitrationCost(bytes)" | "changeAcceptedFeeTokens" | "changeCourtParameters" | "changeCurrencyRates" | "changeGovernor" | "changeGuardian" | "changeJurorProsecutionModule" | "changePinakion" | "changeSortitionModule" | "convertEthToTokenAmount" | "courts" | "createCourt" | "createDispute(uint256,bytes)" | "createDispute(uint256,bytes,address,uint256)" | "currencyRates" | "currentRuling" | "disputeKits" | "disputes" | "draw" | "enableDisputeKits" | "execute" | "executeGovernorProposal" | "executeRuling" | "getDisputeKitsLength" | "getNumberOfRounds" | "getNumberOfVotes" | "getRoundInfo" | "getTimesPerPeriod" | "governor" | "guardian" | "initialize" | "isDisputeKitJumping" | "isSupported" | "jurorProsecutionModule" | "passPeriod" | "pause" | "paused" | "pinakion" | "proxiableUUID" | "setStake" | "setStakeBySortitionModule" | "sortitionModule" | "unpause" | "upgradeToAndCall"): FunctionFragment;
    encodeFunctionData(functionFragment: "addNewDisputeKit", values: [string]): string;
    encodeFunctionData(functionFragment: "appeal", values: [BigNumberish, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "appealCost", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "appealPeriod", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "arbitrationCost(bytes,address)", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "arbitrationCost(bytes)", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "changeAcceptedFeeTokens", values: [string, boolean]): string;
    encodeFunctionData(functionFragment: "changeCourtParameters", values: [
        BigNumberish,
        boolean,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ]
    ]): string;
    encodeFunctionData(functionFragment: "changeCurrencyRates", values: [string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "changeGovernor", values: [string]): string;
    encodeFunctionData(functionFragment: "changeGuardian", values: [string]): string;
    encodeFunctionData(functionFragment: "changeJurorProsecutionModule", values: [string]): string;
    encodeFunctionData(functionFragment: "changePinakion", values: [string]): string;
    encodeFunctionData(functionFragment: "changeSortitionModule", values: [string]): string;
    encodeFunctionData(functionFragment: "convertEthToTokenAmount", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "courts", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "createCourt", values: [
        BigNumberish,
        boolean,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ],
        BytesLike,
        BigNumberish[]
    ]): string;
    encodeFunctionData(functionFragment: "createDispute(uint256,bytes)", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "createDispute(uint256,bytes,address,uint256)", values: [BigNumberish, BytesLike, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "currencyRates", values: [string]): string;
    encodeFunctionData(functionFragment: "currentRuling", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "disputeKits", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "disputes", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "draw", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "enableDisputeKits", values: [BigNumberish, BigNumberish[], boolean]): string;
    encodeFunctionData(functionFragment: "execute", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "executeGovernorProposal", values: [string, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "executeRuling", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getDisputeKitsLength", values?: undefined): string;
    encodeFunctionData(functionFragment: "getNumberOfRounds", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getNumberOfVotes", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getRoundInfo", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getTimesPerPeriod", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "guardian", values?: undefined): string;
    encodeFunctionData(functionFragment: "initialize", values: [
        string,
        string,
        string,
        string,
        string,
        boolean,
        [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ],
        [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ],
        BytesLike,
        string
    ]): string;
    encodeFunctionData(functionFragment: "isDisputeKitJumping", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "isSupported", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "jurorProsecutionModule", values?: undefined): string;
    encodeFunctionData(functionFragment: "passPeriod", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "pause", values?: undefined): string;
    encodeFunctionData(functionFragment: "paused", values?: undefined): string;
    encodeFunctionData(functionFragment: "pinakion", values?: undefined): string;
    encodeFunctionData(functionFragment: "proxiableUUID", values?: undefined): string;
    encodeFunctionData(functionFragment: "setStake", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setStakeBySortitionModule", values: [string, BigNumberish, BigNumberish, boolean]): string;
    encodeFunctionData(functionFragment: "sortitionModule", values?: undefined): string;
    encodeFunctionData(functionFragment: "unpause", values?: undefined): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [string, BytesLike]): string;
    decodeFunctionResult(functionFragment: "addNewDisputeKit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "appeal", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "appealCost", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "appealPeriod", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "arbitrationCost(bytes,address)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "arbitrationCost(bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeAcceptedFeeTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeCourtParameters", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeCurrencyRates", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeGovernor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeGuardian", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeJurorProsecutionModule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changePinakion", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeSortitionModule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "convertEthToTokenAmount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "courts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createCourt", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(uint256,bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(uint256,bytes,address,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "currencyRates", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "currentRuling", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputeKits", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputes", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "draw", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "enableDisputeKits", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "execute", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "executeGovernorProposal", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "executeRuling", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getDisputeKitsLength", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getNumberOfRounds", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getNumberOfVotes", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoundInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getTimesPerPeriod", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "guardian", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isDisputeKitJumping", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isSupported", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "jurorProsecutionModule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "passPeriod", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pause", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "paused", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pinakion", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "proxiableUUID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setStake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setStakeBySortitionModule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sortitionModule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unpause", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
    events: {
        "AcceptedFeeToken(address,bool)": EventFragment;
        "AppealDecision(uint256,address)": EventFragment;
        "AppealPossible(uint256,address)": EventFragment;
        "CourtCreated(uint256,uint96,bool,uint256,uint256,uint256,uint256,uint256[4],uint256[])": EventFragment;
        "CourtJump(uint256,uint256,uint96,uint96)": EventFragment;
        "CourtModified(uint96,bool,uint256,uint256,uint256,uint256,uint256[4])": EventFragment;
        "DisputeCreation(uint256,address)": EventFragment;
        "DisputeKitCreated(uint256,address)": EventFragment;
        "DisputeKitEnabled(uint96,uint256,bool)": EventFragment;
        "DisputeKitJump(uint256,uint256,uint256,uint256)": EventFragment;
        "Draw(address,uint256,uint256,uint256)": EventFragment;
        "Initialized(uint64)": EventFragment;
        "LeftoverRewardSent(uint256,uint256,uint256,uint256,address)": EventFragment;
        "NewCurrencyRate(address,uint64,uint8)": EventFragment;
        "NewPeriod(uint256,uint8)": EventFragment;
        "Paused()": EventFragment;
        "Ruling(address,uint256,uint256)": EventFragment;
        "TokenAndETHShift(address,uint256,uint256,uint256,int256,int256,address)": EventFragment;
        "Unpaused()": EventFragment;
        "Upgraded(address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AcceptedFeeToken"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "AppealDecision"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "AppealPossible"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "CourtCreated"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "CourtJump"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "CourtModified"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeCreation"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeKitCreated"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeKitEnabled"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeKitJump"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Draw"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Initialized"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "LeftoverRewardSent"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewCurrencyRate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewPeriod"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Paused"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Ruling"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "TokenAndETHShift"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Unpaused"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
}
export interface AcceptedFeeTokenEventObject {
    _token: string;
    _accepted: boolean;
}
export type AcceptedFeeTokenEvent = TypedEvent<[
    string,
    boolean
], AcceptedFeeTokenEventObject>;
export type AcceptedFeeTokenEventFilter = TypedEventFilter<AcceptedFeeTokenEvent>;
export interface AppealDecisionEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type AppealDecisionEvent = TypedEvent<[
    BigNumber,
    string
], AppealDecisionEventObject>;
export type AppealDecisionEventFilter = TypedEventFilter<AppealDecisionEvent>;
export interface AppealPossibleEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type AppealPossibleEvent = TypedEvent<[
    BigNumber,
    string
], AppealPossibleEventObject>;
export type AppealPossibleEventFilter = TypedEventFilter<AppealPossibleEvent>;
export interface CourtCreatedEventObject {
    _courtID: BigNumber;
    _parent: BigNumber;
    _hiddenVotes: boolean;
    _minStake: BigNumber;
    _alpha: BigNumber;
    _feeForJuror: BigNumber;
    _jurorsForCourtJump: BigNumber;
    _timesPerPeriod: [BigNumber, BigNumber, BigNumber, BigNumber];
    _supportedDisputeKits: BigNumber[];
}
export type CourtCreatedEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    boolean,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    [
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber
    ],
    BigNumber[]
], CourtCreatedEventObject>;
export type CourtCreatedEventFilter = TypedEventFilter<CourtCreatedEvent>;
export interface CourtJumpEventObject {
    _disputeID: BigNumber;
    _roundID: BigNumber;
    _fromCourtID: BigNumber;
    _toCourtID: BigNumber;
}
export type CourtJumpEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber
], CourtJumpEventObject>;
export type CourtJumpEventFilter = TypedEventFilter<CourtJumpEvent>;
export interface CourtModifiedEventObject {
    _courtID: BigNumber;
    _hiddenVotes: boolean;
    _minStake: BigNumber;
    _alpha: BigNumber;
    _feeForJuror: BigNumber;
    _jurorsForCourtJump: BigNumber;
    _timesPerPeriod: [BigNumber, BigNumber, BigNumber, BigNumber];
}
export type CourtModifiedEvent = TypedEvent<[
    BigNumber,
    boolean,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    [
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber
    ]
], CourtModifiedEventObject>;
export type CourtModifiedEventFilter = TypedEventFilter<CourtModifiedEvent>;
export interface DisputeCreationEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type DisputeCreationEvent = TypedEvent<[
    BigNumber,
    string
], DisputeCreationEventObject>;
export type DisputeCreationEventFilter = TypedEventFilter<DisputeCreationEvent>;
export interface DisputeKitCreatedEventObject {
    _disputeKitID: BigNumber;
    _disputeKitAddress: string;
}
export type DisputeKitCreatedEvent = TypedEvent<[
    BigNumber,
    string
], DisputeKitCreatedEventObject>;
export type DisputeKitCreatedEventFilter = TypedEventFilter<DisputeKitCreatedEvent>;
export interface DisputeKitEnabledEventObject {
    _courtID: BigNumber;
    _disputeKitID: BigNumber;
    _enable: boolean;
}
export type DisputeKitEnabledEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    boolean
], DisputeKitEnabledEventObject>;
export type DisputeKitEnabledEventFilter = TypedEventFilter<DisputeKitEnabledEvent>;
export interface DisputeKitJumpEventObject {
    _disputeID: BigNumber;
    _roundID: BigNumber;
    _fromDisputeKitID: BigNumber;
    _toDisputeKitID: BigNumber;
}
export type DisputeKitJumpEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber
], DisputeKitJumpEventObject>;
export type DisputeKitJumpEventFilter = TypedEventFilter<DisputeKitJumpEvent>;
export interface DrawEventObject {
    _address: string;
    _disputeID: BigNumber;
    _roundID: BigNumber;
    _voteID: BigNumber;
}
export type DrawEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber,
    BigNumber
], DrawEventObject>;
export type DrawEventFilter = TypedEventFilter<DrawEvent>;
export interface InitializedEventObject {
    version: BigNumber;
}
export type InitializedEvent = TypedEvent<[BigNumber], InitializedEventObject>;
export type InitializedEventFilter = TypedEventFilter<InitializedEvent>;
export interface LeftoverRewardSentEventObject {
    _disputeID: BigNumber;
    _roundID: BigNumber;
    _pnkAmount: BigNumber;
    _feeAmount: BigNumber;
    _feeToken: string;
}
export type LeftoverRewardSentEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    string
], LeftoverRewardSentEventObject>;
export type LeftoverRewardSentEventFilter = TypedEventFilter<LeftoverRewardSentEvent>;
export interface NewCurrencyRateEventObject {
    _feeToken: string;
    _rateInEth: BigNumber;
    _rateDecimals: number;
}
export type NewCurrencyRateEvent = TypedEvent<[
    string,
    BigNumber,
    number
], NewCurrencyRateEventObject>;
export type NewCurrencyRateEventFilter = TypedEventFilter<NewCurrencyRateEvent>;
export interface NewPeriodEventObject {
    _disputeID: BigNumber;
    _period: number;
}
export type NewPeriodEvent = TypedEvent<[
    BigNumber,
    number
], NewPeriodEventObject>;
export type NewPeriodEventFilter = TypedEventFilter<NewPeriodEvent>;
export interface PausedEventObject {
}
export type PausedEvent = TypedEvent<[], PausedEventObject>;
export type PausedEventFilter = TypedEventFilter<PausedEvent>;
export interface RulingEventObject {
    _arbitrable: string;
    _disputeID: BigNumber;
    _ruling: BigNumber;
}
export type RulingEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], RulingEventObject>;
export type RulingEventFilter = TypedEventFilter<RulingEvent>;
export interface TokenAndETHShiftEventObject {
    _account: string;
    _disputeID: BigNumber;
    _roundID: BigNumber;
    _degreeOfCoherency: BigNumber;
    _pnkAmount: BigNumber;
    _feeAmount: BigNumber;
    _feeToken: string;
}
export type TokenAndETHShiftEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    string
], TokenAndETHShiftEventObject>;
export type TokenAndETHShiftEventFilter = TypedEventFilter<TokenAndETHShiftEvent>;
export interface UnpausedEventObject {
}
export type UnpausedEvent = TypedEvent<[], UnpausedEventObject>;
export type UnpausedEventFilter = TypedEventFilter<UnpausedEvent>;
export interface UpgradedEventObject {
    newImplementation: string;
}
export type UpgradedEvent = TypedEvent<[string], UpgradedEventObject>;
export type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export interface KlerosCore extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: KlerosCoreInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        addNewDisputeKit(_disputeKitAddress: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        appeal(_disputeID: BigNumberish, _numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        appealCost(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber] & {
            start: BigNumber;
            end: BigNumber;
        }>;
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        changeAcceptedFeeTokens(_feeToken: string, _accepted: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeCourtParameters(_courtID: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeCurrencyRates(_feeToken: string, _rateInEth: BigNumberish, _rateDecimals: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeGuardian(_guardian: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeJurorProsecutionModule(_jurorProsecutionModule: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changePinakion(_pinakion: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeSortitionModule(_sortitionModule: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        convertEthToTokenAmount(_toToken: string, _amountInEth: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        courts(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber,
            boolean
        ] & {
            parent: BigNumber;
            hiddenVotes: boolean;
            minStake: BigNumber;
            alpha: BigNumber;
            feeForJuror: BigNumber;
            jurorsForCourtJump: BigNumber;
            disabled: boolean;
        }>;
        createCourt(_parent: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _supportedDisputeKits: BigNumberish[], overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        currencyRates(arg0: string, overrides?: CallOverrides): Promise<[
            boolean,
            BigNumber,
            number
        ] & {
            feePaymentAccepted: boolean;
            rateInEth: BigNumber;
            rateDecimals: number;
        }>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            boolean
        ] & {
            ruling: BigNumber;
            tied: boolean;
            overridden: boolean;
        }>;
        disputeKits(arg0: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            string,
            number,
            boolean,
            BigNumber
        ] & {
            courtID: BigNumber;
            arbitrated: string;
            period: number;
            ruled: boolean;
            lastPeriodChange: BigNumber;
        }>;
        draw(_disputeID: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        enableDisputeKits(_courtID: BigNumberish, _disputeKitIDs: BigNumberish[], _enable: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        execute(_disputeID: BigNumberish, _round: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        executeRuling(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        getDisputeKitsLength(overrides?: CallOverrides): Promise<[BigNumber]>;
        getNumberOfRounds(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        getNumberOfVotes(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        getRoundInfo(_disputeID: BigNumberish, _round: BigNumberish, overrides?: CallOverrides): Promise<[KlerosCoreBase.RoundStructOutput]>;
        getTimesPerPeriod(_courtID: BigNumberish, overrides?: CallOverrides): Promise<[
            [BigNumber, BigNumber, BigNumber, BigNumber]
        ] & {
            timesPerPeriod: [BigNumber, BigNumber, BigNumber, BigNumber];
        }>;
        governor(overrides?: CallOverrides): Promise<[string]>;
        guardian(overrides?: CallOverrides): Promise<[string]>;
        initialize(_governor: string, _guardian: string, _pinakion: string, _jurorProsecutionModule: string, _disputeKit: string, _hiddenVotes: boolean, _courtParameters: [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ], _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _sortitionModuleAddress: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        isDisputeKitJumping(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[boolean]>;
        isSupported(_courtID: BigNumberish, _disputeKitID: BigNumberish, overrides?: CallOverrides): Promise<[boolean]>;
        jurorProsecutionModule(overrides?: CallOverrides): Promise<[string]>;
        passPeriod(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        pause(overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        paused(overrides?: CallOverrides): Promise<[boolean]>;
        pinakion(overrides?: CallOverrides): Promise<[string]>;
        proxiableUUID(overrides?: CallOverrides): Promise<[string]>;
        setStake(_courtID: BigNumberish, _newStake: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        setStakeBySortitionModule(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        sortitionModule(overrides?: CallOverrides): Promise<[string]>;
        unpause(overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    addNewDisputeKit(_disputeKitAddress: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    appeal(_disputeID: BigNumberish, _numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    appealCost(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber] & {
        start: BigNumber;
        end: BigNumber;
    }>;
    "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    changeAcceptedFeeTokens(_feeToken: string, _accepted: boolean, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeCourtParameters(_courtID: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeCurrencyRates(_feeToken: string, _rateInEth: BigNumberish, _rateDecimals: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeGovernor(_governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeGuardian(_guardian: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeJurorProsecutionModule(_jurorProsecutionModule: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changePinakion(_pinakion: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeSortitionModule(_sortitionModule: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    convertEthToTokenAmount(_toToken: string, _amountInEth: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    courts(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        boolean,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        boolean
    ] & {
        parent: BigNumber;
        hiddenVotes: boolean;
        minStake: BigNumber;
        alpha: BigNumber;
        feeForJuror: BigNumber;
        jurorsForCourtJump: BigNumber;
        disabled: boolean;
    }>;
    createCourt(_parent: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _supportedDisputeKits: BigNumberish[], overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    currencyRates(arg0: string, overrides?: CallOverrides): Promise<[
        boolean,
        BigNumber,
        number
    ] & {
        feePaymentAccepted: boolean;
        rateInEth: BigNumber;
        rateDecimals: number;
    }>;
    currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        boolean,
        boolean
    ] & {
        ruling: BigNumber;
        tied: boolean;
        overridden: boolean;
    }>;
    disputeKits(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
    disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        string,
        number,
        boolean,
        BigNumber
    ] & {
        courtID: BigNumber;
        arbitrated: string;
        period: number;
        ruled: boolean;
        lastPeriodChange: BigNumber;
    }>;
    draw(_disputeID: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    enableDisputeKits(_courtID: BigNumberish, _disputeKitIDs: BigNumberish[], _enable: boolean, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    execute(_disputeID: BigNumberish, _round: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    executeRuling(_disputeID: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    getDisputeKitsLength(overrides?: CallOverrides): Promise<BigNumber>;
    getNumberOfRounds(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    getNumberOfVotes(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    getRoundInfo(_disputeID: BigNumberish, _round: BigNumberish, overrides?: CallOverrides): Promise<KlerosCoreBase.RoundStructOutput>;
    getTimesPerPeriod(_courtID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber, BigNumber]>;
    governor(overrides?: CallOverrides): Promise<string>;
    guardian(overrides?: CallOverrides): Promise<string>;
    initialize(_governor: string, _guardian: string, _pinakion: string, _jurorProsecutionModule: string, _disputeKit: string, _hiddenVotes: boolean, _courtParameters: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _sortitionModuleAddress: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    isDisputeKitJumping(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    isSupported(_courtID: BigNumberish, _disputeKitID: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    jurorProsecutionModule(overrides?: CallOverrides): Promise<string>;
    passPeriod(_disputeID: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    pause(overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    paused(overrides?: CallOverrides): Promise<boolean>;
    pinakion(overrides?: CallOverrides): Promise<string>;
    proxiableUUID(overrides?: CallOverrides): Promise<string>;
    setStake(_courtID: BigNumberish, _newStake: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    setStakeBySortitionModule(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    sortitionModule(overrides?: CallOverrides): Promise<string>;
    unpause(overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        addNewDisputeKit(_disputeKitAddress: string, overrides?: CallOverrides): Promise<void>;
        appeal(_disputeID: BigNumberish, _numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<void>;
        appealCost(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber] & {
            start: BigNumber;
            end: BigNumber;
        }>;
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        changeAcceptedFeeTokens(_feeToken: string, _accepted: boolean, overrides?: CallOverrides): Promise<void>;
        changeCourtParameters(_courtID: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: CallOverrides): Promise<void>;
        changeCurrencyRates(_feeToken: string, _rateInEth: BigNumberish, _rateDecimals: BigNumberish, overrides?: CallOverrides): Promise<void>;
        changeGovernor(_governor: string, overrides?: CallOverrides): Promise<void>;
        changeGuardian(_guardian: string, overrides?: CallOverrides): Promise<void>;
        changeJurorProsecutionModule(_jurorProsecutionModule: string, overrides?: CallOverrides): Promise<void>;
        changePinakion(_pinakion: string, overrides?: CallOverrides): Promise<void>;
        changeSortitionModule(_sortitionModule: string, overrides?: CallOverrides): Promise<void>;
        convertEthToTokenAmount(_toToken: string, _amountInEth: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        courts(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber,
            boolean
        ] & {
            parent: BigNumber;
            hiddenVotes: boolean;
            minStake: BigNumber;
            alpha: BigNumber;
            feeForJuror: BigNumber;
            jurorsForCourtJump: BigNumber;
            disabled: boolean;
        }>;
        createCourt(_parent: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _supportedDisputeKits: BigNumberish[], overrides?: CallOverrides): Promise<void>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        currencyRates(arg0: string, overrides?: CallOverrides): Promise<[
            boolean,
            BigNumber,
            number
        ] & {
            feePaymentAccepted: boolean;
            rateInEth: BigNumber;
            rateDecimals: number;
        }>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            boolean
        ] & {
            ruling: BigNumber;
            tied: boolean;
            overridden: boolean;
        }>;
        disputeKits(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            string,
            number,
            boolean,
            BigNumber
        ] & {
            courtID: BigNumber;
            arbitrated: string;
            period: number;
            ruled: boolean;
            lastPeriodChange: BigNumber;
        }>;
        draw(_disputeID: BigNumberish, _iterations: BigNumberish, overrides?: CallOverrides): Promise<void>;
        enableDisputeKits(_courtID: BigNumberish, _disputeKitIDs: BigNumberish[], _enable: boolean, overrides?: CallOverrides): Promise<void>;
        execute(_disputeID: BigNumberish, _round: BigNumberish, _iterations: BigNumberish, overrides?: CallOverrides): Promise<void>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: CallOverrides): Promise<void>;
        executeRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<void>;
        getDisputeKitsLength(overrides?: CallOverrides): Promise<BigNumber>;
        getNumberOfRounds(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getNumberOfVotes(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getRoundInfo(_disputeID: BigNumberish, _round: BigNumberish, overrides?: CallOverrides): Promise<KlerosCoreBase.RoundStructOutput>;
        getTimesPerPeriod(_courtID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber, BigNumber]>;
        governor(overrides?: CallOverrides): Promise<string>;
        guardian(overrides?: CallOverrides): Promise<string>;
        initialize(_governor: string, _guardian: string, _pinakion: string, _jurorProsecutionModule: string, _disputeKit: string, _hiddenVotes: boolean, _courtParameters: [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ], _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _sortitionModuleAddress: string, overrides?: CallOverrides): Promise<void>;
        isDisputeKitJumping(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        isSupported(_courtID: BigNumberish, _disputeKitID: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        jurorProsecutionModule(overrides?: CallOverrides): Promise<string>;
        passPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<void>;
        pause(overrides?: CallOverrides): Promise<void>;
        paused(overrides?: CallOverrides): Promise<boolean>;
        pinakion(overrides?: CallOverrides): Promise<string>;
        proxiableUUID(overrides?: CallOverrides): Promise<string>;
        setStake(_courtID: BigNumberish, _newStake: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setStakeBySortitionModule(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: CallOverrides): Promise<void>;
        sortitionModule(overrides?: CallOverrides): Promise<string>;
        unpause(overrides?: CallOverrides): Promise<void>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "AcceptedFeeToken(address,bool)"(_token?: string | null, _accepted?: boolean | null): AcceptedFeeTokenEventFilter;
        AcceptedFeeToken(_token?: string | null, _accepted?: boolean | null): AcceptedFeeTokenEventFilter;
        "AppealDecision(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealDecisionEventFilter;
        AppealDecision(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealDecisionEventFilter;
        "AppealPossible(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealPossibleEventFilter;
        AppealPossible(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealPossibleEventFilter;
        "CourtCreated(uint256,uint96,bool,uint256,uint256,uint256,uint256,uint256[4],uint256[])"(_courtID?: BigNumberish | null, _parent?: BigNumberish | null, _hiddenVotes?: null, _minStake?: null, _alpha?: null, _feeForJuror?: null, _jurorsForCourtJump?: null, _timesPerPeriod?: null, _supportedDisputeKits?: null): CourtCreatedEventFilter;
        CourtCreated(_courtID?: BigNumberish | null, _parent?: BigNumberish | null, _hiddenVotes?: null, _minStake?: null, _alpha?: null, _feeForJuror?: null, _jurorsForCourtJump?: null, _timesPerPeriod?: null, _supportedDisputeKits?: null): CourtCreatedEventFilter;
        "CourtJump(uint256,uint256,uint96,uint96)"(_disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _fromCourtID?: BigNumberish | null, _toCourtID?: null): CourtJumpEventFilter;
        CourtJump(_disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _fromCourtID?: BigNumberish | null, _toCourtID?: null): CourtJumpEventFilter;
        "CourtModified(uint96,bool,uint256,uint256,uint256,uint256,uint256[4])"(_courtID?: BigNumberish | null, _hiddenVotes?: null, _minStake?: null, _alpha?: null, _feeForJuror?: null, _jurorsForCourtJump?: null, _timesPerPeriod?: null): CourtModifiedEventFilter;
        CourtModified(_courtID?: BigNumberish | null, _hiddenVotes?: null, _minStake?: null, _alpha?: null, _feeForJuror?: null, _jurorsForCourtJump?: null, _timesPerPeriod?: null): CourtModifiedEventFilter;
        "DisputeCreation(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
        DisputeCreation(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
        "DisputeKitCreated(uint256,address)"(_disputeKitID?: BigNumberish | null, _disputeKitAddress?: string | null): DisputeKitCreatedEventFilter;
        DisputeKitCreated(_disputeKitID?: BigNumberish | null, _disputeKitAddress?: string | null): DisputeKitCreatedEventFilter;
        "DisputeKitEnabled(uint96,uint256,bool)"(_courtID?: BigNumberish | null, _disputeKitID?: BigNumberish | null, _enable?: boolean | null): DisputeKitEnabledEventFilter;
        DisputeKitEnabled(_courtID?: BigNumberish | null, _disputeKitID?: BigNumberish | null, _enable?: boolean | null): DisputeKitEnabledEventFilter;
        "DisputeKitJump(uint256,uint256,uint256,uint256)"(_disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _fromDisputeKitID?: BigNumberish | null, _toDisputeKitID?: null): DisputeKitJumpEventFilter;
        DisputeKitJump(_disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _fromDisputeKitID?: BigNumberish | null, _toDisputeKitID?: null): DisputeKitJumpEventFilter;
        "Draw(address,uint256,uint256,uint256)"(_address?: string | null, _disputeID?: BigNumberish | null, _roundID?: null, _voteID?: null): DrawEventFilter;
        Draw(_address?: string | null, _disputeID?: BigNumberish | null, _roundID?: null, _voteID?: null): DrawEventFilter;
        "Initialized(uint64)"(version?: null): InitializedEventFilter;
        Initialized(version?: null): InitializedEventFilter;
        "LeftoverRewardSent(uint256,uint256,uint256,uint256,address)"(_disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _pnkAmount?: null, _feeAmount?: null, _feeToken?: null): LeftoverRewardSentEventFilter;
        LeftoverRewardSent(_disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _pnkAmount?: null, _feeAmount?: null, _feeToken?: null): LeftoverRewardSentEventFilter;
        "NewCurrencyRate(address,uint64,uint8)"(_feeToken?: string | null, _rateInEth?: null, _rateDecimals?: null): NewCurrencyRateEventFilter;
        NewCurrencyRate(_feeToken?: string | null, _rateInEth?: null, _rateDecimals?: null): NewCurrencyRateEventFilter;
        "NewPeriod(uint256,uint8)"(_disputeID?: BigNumberish | null, _period?: null): NewPeriodEventFilter;
        NewPeriod(_disputeID?: BigNumberish | null, _period?: null): NewPeriodEventFilter;
        "Paused()"(): PausedEventFilter;
        Paused(): PausedEventFilter;
        "Ruling(address,uint256,uint256)"(_arbitrable?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        Ruling(_arbitrable?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        "TokenAndETHShift(address,uint256,uint256,uint256,int256,int256,address)"(_account?: string | null, _disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _degreeOfCoherency?: null, _pnkAmount?: null, _feeAmount?: null, _feeToken?: null): TokenAndETHShiftEventFilter;
        TokenAndETHShift(_account?: string | null, _disputeID?: BigNumberish | null, _roundID?: BigNumberish | null, _degreeOfCoherency?: null, _pnkAmount?: null, _feeAmount?: null, _feeToken?: null): TokenAndETHShiftEventFilter;
        "Unpaused()"(): UnpausedEventFilter;
        Unpaused(): UnpausedEventFilter;
        "Upgraded(address)"(newImplementation?: string | null): UpgradedEventFilter;
        Upgraded(newImplementation?: string | null): UpgradedEventFilter;
    };
    estimateGas: {
        addNewDisputeKit(_disputeKitAddress: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        appeal(_disputeID: BigNumberish, _numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        appealCost(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        changeAcceptedFeeTokens(_feeToken: string, _accepted: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeCourtParameters(_courtID: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeCurrencyRates(_feeToken: string, _rateInEth: BigNumberish, _rateDecimals: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeGuardian(_guardian: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeJurorProsecutionModule(_jurorProsecutionModule: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changePinakion(_pinakion: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeSortitionModule(_sortitionModule: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        convertEthToTokenAmount(_toToken: string, _amountInEth: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        courts(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        createCourt(_parent: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _supportedDisputeKits: BigNumberish[], overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        currencyRates(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        disputeKits(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        draw(_disputeID: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        enableDisputeKits(_courtID: BigNumberish, _disputeKitIDs: BigNumberish[], _enable: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        execute(_disputeID: BigNumberish, _round: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        executeRuling(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        getDisputeKitsLength(overrides?: CallOverrides): Promise<BigNumber>;
        getNumberOfRounds(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getNumberOfVotes(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getRoundInfo(_disputeID: BigNumberish, _round: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getTimesPerPeriod(_courtID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<BigNumber>;
        guardian(overrides?: CallOverrides): Promise<BigNumber>;
        initialize(_governor: string, _guardian: string, _pinakion: string, _jurorProsecutionModule: string, _disputeKit: string, _hiddenVotes: boolean, _courtParameters: [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ], _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _sortitionModuleAddress: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        isDisputeKitJumping(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        isSupported(_courtID: BigNumberish, _disputeKitID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        jurorProsecutionModule(overrides?: CallOverrides): Promise<BigNumber>;
        passPeriod(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        pause(overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        paused(overrides?: CallOverrides): Promise<BigNumber>;
        pinakion(overrides?: CallOverrides): Promise<BigNumber>;
        proxiableUUID(overrides?: CallOverrides): Promise<BigNumber>;
        setStake(_courtID: BigNumberish, _newStake: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        setStakeBySortitionModule(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        sortitionModule(overrides?: CallOverrides): Promise<BigNumber>;
        unpause(overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        addNewDisputeKit(_disputeKitAddress: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        appeal(_disputeID: BigNumberish, _numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        appealCost(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        changeAcceptedFeeTokens(_feeToken: string, _accepted: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeCourtParameters(_courtID: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeCurrencyRates(_feeToken: string, _rateInEth: BigNumberish, _rateDecimals: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeGuardian(_guardian: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeJurorProsecutionModule(_jurorProsecutionModule: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changePinakion(_pinakion: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeSortitionModule(_sortitionModule: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        convertEthToTokenAmount(_toToken: string, _amountInEth: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        courts(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        createCourt(_parent: BigNumberish, _hiddenVotes: boolean, _minStake: BigNumberish, _alpha: BigNumberish, _feeForJuror: BigNumberish, _jurorsForCourtJump: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _supportedDisputeKits: BigNumberish[], overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        currencyRates(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        disputeKits(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        draw(_disputeID: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        enableDisputeKits(_courtID: BigNumberish, _disputeKitIDs: BigNumberish[], _enable: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        execute(_disputeID: BigNumberish, _round: BigNumberish, _iterations: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        executeRuling(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        getDisputeKitsLength(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getNumberOfRounds(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getNumberOfVotes(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoundInfo(_disputeID: BigNumberish, _round: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getTimesPerPeriod(_courtID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        guardian(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(_governor: string, _guardian: string, _pinakion: string, _jurorProsecutionModule: string, _disputeKit: string, _hiddenVotes: boolean, _courtParameters: [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ], _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], _sortitionExtraData: BytesLike, _sortitionModuleAddress: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        isDisputeKitJumping(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isSupported(_courtID: BigNumberish, _disputeKitID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        jurorProsecutionModule(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        passPeriod(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        pause(overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        paused(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        pinakion(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        proxiableUUID(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setStake(_courtID: BigNumberish, _newStake: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        setStakeBySortitionModule(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        sortitionModule(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        unpause(overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
