import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../common";
export interface PolicyRegistryInterface extends utils.Interface {
    functions: {
        "changeGovernor(address)": FunctionFragment;
        "governor()": FunctionFragment;
        "initialize(address)": FunctionFragment;
        "policies(uint256)": FunctionFragment;
        "proxiableUUID()": FunctionFragment;
        "setPolicy(uint256,string,string)": FunctionFragment;
        "upgradeToAndCall(address,bytes)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "changeGovernor" | "governor" | "initialize" | "policies" | "proxiableUUID" | "setPolicy" | "upgradeToAndCall"): FunctionFragment;
    encodeFunctionData(functionFragment: "changeGovernor", values: [string]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "initialize", values: [string]): string;
    encodeFunctionData(functionFragment: "policies", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "proxiableUUID", values?: undefined): string;
    encodeFunctionData(functionFragment: "setPolicy", values: [BigNumberish, string, string]): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [string, BytesLike]): string;
    decodeFunctionResult(functionFragment: "changeGovernor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "policies", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "proxiableUUID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPolicy", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
    events: {
        "Initialized(uint64)": EventFragment;
        "PolicyUpdate(uint256,string,string)": EventFragment;
        "Upgraded(address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Initialized"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PolicyUpdate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
}
export interface InitializedEventObject {
    version: BigNumber;
}
export type InitializedEvent = TypedEvent<[BigNumber], InitializedEventObject>;
export type InitializedEventFilter = TypedEventFilter<InitializedEvent>;
export interface PolicyUpdateEventObject {
    _courtID: BigNumber;
    _courtName: string;
    _policy: string;
}
export type PolicyUpdateEvent = TypedEvent<[
    BigNumber,
    string,
    string
], PolicyUpdateEventObject>;
export type PolicyUpdateEventFilter = TypedEventFilter<PolicyUpdateEvent>;
export interface UpgradedEventObject {
    newImplementation: string;
}
export type UpgradedEvent = TypedEvent<[string], UpgradedEventObject>;
export type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export interface PolicyRegistry extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: PolicyRegistryInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        governor(overrides?: CallOverrides): Promise<[string]>;
        initialize(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        policies(arg0: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        proxiableUUID(overrides?: CallOverrides): Promise<[string]>;
        setPolicy(_courtID: BigNumberish, _courtName: string, _policy: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    changeGovernor(_governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    governor(overrides?: CallOverrides): Promise<string>;
    initialize(_governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    policies(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
    proxiableUUID(overrides?: CallOverrides): Promise<string>;
    setPolicy(_courtID: BigNumberish, _courtName: string, _policy: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        changeGovernor(_governor: string, overrides?: CallOverrides): Promise<void>;
        governor(overrides?: CallOverrides): Promise<string>;
        initialize(_governor: string, overrides?: CallOverrides): Promise<void>;
        policies(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
        proxiableUUID(overrides?: CallOverrides): Promise<string>;
        setPolicy(_courtID: BigNumberish, _courtName: string, _policy: string, overrides?: CallOverrides): Promise<void>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Initialized(uint64)"(version?: null): InitializedEventFilter;
        Initialized(version?: null): InitializedEventFilter;
        "PolicyUpdate(uint256,string,string)"(_courtID?: BigNumberish | null, _courtName?: null, _policy?: null): PolicyUpdateEventFilter;
        PolicyUpdate(_courtID?: BigNumberish | null, _courtName?: null, _policy?: null): PolicyUpdateEventFilter;
        "Upgraded(address)"(newImplementation?: string | null): UpgradedEventFilter;
        Upgraded(newImplementation?: string | null): UpgradedEventFilter;
    };
    estimateGas: {
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<BigNumber>;
        initialize(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        policies(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        proxiableUUID(overrides?: CallOverrides): Promise<BigNumber>;
        setPolicy(_courtID: BigNumberish, _courtName: string, _policy: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        governor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        policies(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        proxiableUUID(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setPolicy(_courtID: BigNumberish, _courtName: string, _policy: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
