import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export interface ArbitrableExampleInterface extends utils.Interface {
    functions: {
        "arbitrator()": FunctionFragment;
        "arbitratorExtraData()": FunctionFragment;
        "changeArbitrator(address)": FunctionFragment;
        "changeArbitratorExtraData(bytes)": FunctionFragment;
        "changeDisputeTemplate(string,string)": FunctionFragment;
        "changeTemplateRegistry(address)": FunctionFragment;
        "createDispute(string,uint256)": FunctionFragment;
        "createDispute(string)": FunctionFragment;
        "disputes(uint256)": FunctionFragment;
        "externalIDtoLocalID(uint256)": FunctionFragment;
        "governor()": FunctionFragment;
        "rule(uint256,uint256)": FunctionFragment;
        "templateId()": FunctionFragment;
        "templateRegistry()": FunctionFragment;
        "weth()": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "arbitrator" | "arbitratorExtraData" | "changeArbitrator" | "changeArbitratorExtraData" | "changeDisputeTemplate" | "changeTemplateRegistry" | "createDispute(string,uint256)" | "createDispute(string)" | "disputes" | "externalIDtoLocalID" | "governor" | "rule" | "templateId" | "templateRegistry" | "weth"): FunctionFragment;
    encodeFunctionData(functionFragment: "arbitrator", values?: undefined): string;
    encodeFunctionData(functionFragment: "arbitratorExtraData", values?: undefined): string;
    encodeFunctionData(functionFragment: "changeArbitrator", values: [string]): string;
    encodeFunctionData(functionFragment: "changeArbitratorExtraData", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "changeDisputeTemplate", values: [string, string]): string;
    encodeFunctionData(functionFragment: "changeTemplateRegistry", values: [string]): string;
    encodeFunctionData(functionFragment: "createDispute(string,uint256)", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "createDispute(string)", values: [string]): string;
    encodeFunctionData(functionFragment: "disputes", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "externalIDtoLocalID", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "rule", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "templateId", values?: undefined): string;
    encodeFunctionData(functionFragment: "templateRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "weth", values?: undefined): string;
    decodeFunctionResult(functionFragment: "arbitrator", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "arbitratorExtraData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeArbitrator", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeArbitratorExtraData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeDisputeTemplate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeTemplateRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(string,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(string)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputes", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "externalIDtoLocalID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "templateId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "templateRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "weth", data: BytesLike): Result;
    events: {
        "Action(string)": EventFragment;
        "DisputeRequest(address,uint256,uint256,uint256,string)": EventFragment;
        "Ruling(address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Action"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeRequest"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Ruling"): EventFragment;
}
export interface ActionEventObject {
    _action: string;
}
export type ActionEvent = TypedEvent<[string], ActionEventObject>;
export type ActionEventFilter = TypedEventFilter<ActionEvent>;
export interface DisputeRequestEventObject {
    _arbitrator: string;
    _arbitrableDisputeID: BigNumber;
    _externalDisputeID: BigNumber;
    _templateId: BigNumber;
    _templateUri: string;
}
export type DisputeRequestEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    string
], DisputeRequestEventObject>;
export type DisputeRequestEventFilter = TypedEventFilter<DisputeRequestEvent>;
export interface RulingEventObject {
    _arbitrator: string;
    _disputeID: BigNumber;
    _ruling: BigNumber;
}
export type RulingEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], RulingEventObject>;
export type RulingEventFilter = TypedEventFilter<RulingEvent>;
export interface ArbitrableExample extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ArbitrableExampleInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        arbitrator(overrides?: CallOverrides): Promise<[string]>;
        arbitratorExtraData(overrides?: CallOverrides): Promise<[string]>;
        changeArbitrator(_arbitrator: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeArbitratorExtraData(_arbitratorExtraData: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeDisputeTemplate(_templateData: string, _templateDataMappings: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "createDispute(string,uint256)"(_action: string, _feeInWeth: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "createDispute(string)"(_action: string, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            boolean,
            BigNumber,
            BigNumber
        ] & {
            isRuled: boolean;
            ruling: BigNumber;
            numberOfRulingOptions: BigNumber;
        }>;
        externalIDtoLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        governor(overrides?: CallOverrides): Promise<[string]>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        templateId(overrides?: CallOverrides): Promise<[BigNumber]>;
        templateRegistry(overrides?: CallOverrides): Promise<[string]>;
        weth(overrides?: CallOverrides): Promise<[string]>;
    };
    arbitrator(overrides?: CallOverrides): Promise<string>;
    arbitratorExtraData(overrides?: CallOverrides): Promise<string>;
    changeArbitrator(_arbitrator: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeArbitratorExtraData(_arbitratorExtraData: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeDisputeTemplate(_templateData: string, _templateDataMappings: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "createDispute(string,uint256)"(_action: string, _feeInWeth: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "createDispute(string)"(_action: string, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
        boolean,
        BigNumber,
        BigNumber
    ] & {
        isRuled: boolean;
        ruling: BigNumber;
        numberOfRulingOptions: BigNumber;
    }>;
    externalIDtoLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    governor(overrides?: CallOverrides): Promise<string>;
    rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    templateId(overrides?: CallOverrides): Promise<BigNumber>;
    templateRegistry(overrides?: CallOverrides): Promise<string>;
    weth(overrides?: CallOverrides): Promise<string>;
    callStatic: {
        arbitrator(overrides?: CallOverrides): Promise<string>;
        arbitratorExtraData(overrides?: CallOverrides): Promise<string>;
        changeArbitrator(_arbitrator: string, overrides?: CallOverrides): Promise<void>;
        changeArbitratorExtraData(_arbitratorExtraData: BytesLike, overrides?: CallOverrides): Promise<void>;
        changeDisputeTemplate(_templateData: string, _templateDataMappings: string, overrides?: CallOverrides): Promise<void>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: CallOverrides): Promise<void>;
        "createDispute(string,uint256)"(_action: string, _feeInWeth: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(string)"(_action: string, overrides?: CallOverrides): Promise<BigNumber>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            boolean,
            BigNumber,
            BigNumber
        ] & {
            isRuled: boolean;
            ruling: BigNumber;
            numberOfRulingOptions: BigNumber;
        }>;
        externalIDtoLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<string>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: CallOverrides): Promise<void>;
        templateId(overrides?: CallOverrides): Promise<BigNumber>;
        templateRegistry(overrides?: CallOverrides): Promise<string>;
        weth(overrides?: CallOverrides): Promise<string>;
    };
    filters: {
        "Action(string)"(_action?: string | null): ActionEventFilter;
        Action(_action?: string | null): ActionEventFilter;
        "DisputeRequest(address,uint256,uint256,uint256,string)"(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        DisputeRequest(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        "Ruling(address,uint256,uint256)"(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        Ruling(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
    };
    estimateGas: {
        arbitrator(overrides?: CallOverrides): Promise<BigNumber>;
        arbitratorExtraData(overrides?: CallOverrides): Promise<BigNumber>;
        changeArbitrator(_arbitrator: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeArbitratorExtraData(_arbitratorExtraData: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeDisputeTemplate(_templateData: string, _templateDataMappings: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        "createDispute(string,uint256)"(_action: string, _feeInWeth: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        "createDispute(string)"(_action: string, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        externalIDtoLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<BigNumber>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        templateId(overrides?: CallOverrides): Promise<BigNumber>;
        templateRegistry(overrides?: CallOverrides): Promise<BigNumber>;
        weth(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        arbitrator(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        arbitratorExtraData(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        changeArbitrator(_arbitrator: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeArbitratorExtraData(_arbitratorExtraData: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeDisputeTemplate(_templateData: string, _templateDataMappings: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "createDispute(string,uint256)"(_action: string, _feeInWeth: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "createDispute(string)"(_action: string, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        externalIDtoLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        templateId(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        templateRegistry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        weth(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
