import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export interface DisputeResolverInterface extends utils.Interface {
    functions: {
        "arbitrator()": FunctionFragment;
        "arbitratorDisputeIDToLocalID(uint256)": FunctionFragment;
        "changeArbitrator(address)": FunctionFragment;
        "changeGovernor(address)": FunctionFragment;
        "changeTemplateRegistry(address)": FunctionFragment;
        "createDisputeForTemplate(bytes,string,string,uint256)": FunctionFragment;
        "createDisputeForTemplateUri(bytes,string,uint256)": FunctionFragment;
        "disputes(uint256)": FunctionFragment;
        "governor()": FunctionFragment;
        "rule(uint256,uint256)": FunctionFragment;
        "templateRegistry()": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "arbitrator" | "arbitratorDisputeIDToLocalID" | "changeArbitrator" | "changeGovernor" | "changeTemplateRegistry" | "createDisputeForTemplate" | "createDisputeForTemplateUri" | "disputes" | "governor" | "rule" | "templateRegistry"): FunctionFragment;
    encodeFunctionData(functionFragment: "arbitrator", values?: undefined): string;
    encodeFunctionData(functionFragment: "arbitratorDisputeIDToLocalID", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "changeArbitrator", values: [string]): string;
    encodeFunctionData(functionFragment: "changeGovernor", values: [string]): string;
    encodeFunctionData(functionFragment: "changeTemplateRegistry", values: [string]): string;
    encodeFunctionData(functionFragment: "createDisputeForTemplate", values: [BytesLike, string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "createDisputeForTemplateUri", values: [BytesLike, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "disputes", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "rule", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "templateRegistry", values?: undefined): string;
    decodeFunctionResult(functionFragment: "arbitrator", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "arbitratorDisputeIDToLocalID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeArbitrator", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeGovernor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeTemplateRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDisputeForTemplate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDisputeForTemplateUri", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputes", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "templateRegistry", data: BytesLike): Result;
    events: {
        "DisputeRequest(address,uint256,uint256,uint256,string)": EventFragment;
        "Ruling(address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "DisputeRequest"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Ruling"): EventFragment;
}
export interface DisputeRequestEventObject {
    _arbitrator: string;
    _arbitrableDisputeID: BigNumber;
    _externalDisputeID: BigNumber;
    _templateId: BigNumber;
    _templateUri: string;
}
export type DisputeRequestEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    string
], DisputeRequestEventObject>;
export type DisputeRequestEventFilter = TypedEventFilter<DisputeRequestEvent>;
export interface RulingEventObject {
    _arbitrator: string;
    _disputeID: BigNumber;
    _ruling: BigNumber;
}
export type RulingEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], RulingEventObject>;
export type RulingEventFilter = TypedEventFilter<RulingEvent>;
export interface DisputeResolver extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: DisputeResolverInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        arbitrator(overrides?: CallOverrides): Promise<[string]>;
        arbitratorDisputeIDToLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        changeArbitrator(_arbitrator: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        createDisputeForTemplate(_arbitratorExtraData: BytesLike, _disputeTemplate: string, _disputeTemplateDataMappings: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        createDisputeForTemplateUri(_arbitratorExtraData: BytesLike, _disputeTemplateUri: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            boolean,
            BigNumber,
            BigNumber
        ] & {
            arbitratorExtraData: string;
            isRuled: boolean;
            ruling: BigNumber;
            numberOfRulingOptions: BigNumber;
        }>;
        governor(overrides?: CallOverrides): Promise<[string]>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        templateRegistry(overrides?: CallOverrides): Promise<[string]>;
    };
    arbitrator(overrides?: CallOverrides): Promise<string>;
    arbitratorDisputeIDToLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    changeArbitrator(_arbitrator: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeGovernor(_governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    createDisputeForTemplate(_arbitratorExtraData: BytesLike, _disputeTemplate: string, _disputeTemplateDataMappings: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    createDisputeForTemplateUri(_arbitratorExtraData: BytesLike, _disputeTemplateUri: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
        string,
        boolean,
        BigNumber,
        BigNumber
    ] & {
        arbitratorExtraData: string;
        isRuled: boolean;
        ruling: BigNumber;
        numberOfRulingOptions: BigNumber;
    }>;
    governor(overrides?: CallOverrides): Promise<string>;
    rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    templateRegistry(overrides?: CallOverrides): Promise<string>;
    callStatic: {
        arbitrator(overrides?: CallOverrides): Promise<string>;
        arbitratorDisputeIDToLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        changeArbitrator(_arbitrator: string, overrides?: CallOverrides): Promise<void>;
        changeGovernor(_governor: string, overrides?: CallOverrides): Promise<void>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: CallOverrides): Promise<void>;
        createDisputeForTemplate(_arbitratorExtraData: BytesLike, _disputeTemplate: string, _disputeTemplateDataMappings: string, _numberOfRulingOptions: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        createDisputeForTemplateUri(_arbitratorExtraData: BytesLike, _disputeTemplateUri: string, _numberOfRulingOptions: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            boolean,
            BigNumber,
            BigNumber
        ] & {
            arbitratorExtraData: string;
            isRuled: boolean;
            ruling: BigNumber;
            numberOfRulingOptions: BigNumber;
        }>;
        governor(overrides?: CallOverrides): Promise<string>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: CallOverrides): Promise<void>;
        templateRegistry(overrides?: CallOverrides): Promise<string>;
    };
    filters: {
        "DisputeRequest(address,uint256,uint256,uint256,string)"(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        DisputeRequest(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        "Ruling(address,uint256,uint256)"(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        Ruling(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
    };
    estimateGas: {
        arbitrator(overrides?: CallOverrides): Promise<BigNumber>;
        arbitratorDisputeIDToLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        changeArbitrator(_arbitrator: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        createDisputeForTemplate(_arbitratorExtraData: BytesLike, _disputeTemplate: string, _disputeTemplateDataMappings: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        createDisputeForTemplateUri(_arbitratorExtraData: BytesLike, _disputeTemplateUri: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<BigNumber>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        templateRegistry(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        arbitrator(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        arbitratorDisputeIDToLocalID(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        changeArbitrator(_arbitrator: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeTemplateRegistry(_templateRegistry: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        createDisputeForTemplate(_arbitratorExtraData: BytesLike, _disputeTemplate: string, _disputeTemplateDataMappings: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        createDisputeForTemplateUri(_arbitratorExtraData: BytesLike, _disputeTemplateUri: string, _numberOfRulingOptions: BigNumberish, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        disputes(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        rule(_arbitratorDisputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        templateRegistry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
