import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export interface IArbitratorV2Interface extends utils.Interface {
    functions: {
        "arbitrationCost(bytes,address)": FunctionFragment;
        "arbitrationCost(bytes)": FunctionFragment;
        "createDispute(uint256,bytes)": FunctionFragment;
        "createDispute(uint256,bytes,address,uint256)": FunctionFragment;
        "currentRuling(uint256)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "arbitrationCost(bytes,address)" | "arbitrationCost(bytes)" | "createDispute(uint256,bytes)" | "createDispute(uint256,bytes,address,uint256)" | "currentRuling"): FunctionFragment;
    encodeFunctionData(functionFragment: "arbitrationCost(bytes,address)", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "arbitrationCost(bytes)", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "createDispute(uint256,bytes)", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "createDispute(uint256,bytes,address,uint256)", values: [BigNumberish, BytesLike, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "currentRuling", values: [BigNumberish]): string;
    decodeFunctionResult(functionFragment: "arbitrationCost(bytes,address)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "arbitrationCost(bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(uint256,bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(uint256,bytes,address,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "currentRuling", data: BytesLike): Result;
    events: {
        "AcceptedFeeToken(address,bool)": EventFragment;
        "DisputeCreation(uint256,address)": EventFragment;
        "NewCurrencyRate(address,uint64,uint8)": EventFragment;
        "Ruling(address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AcceptedFeeToken"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeCreation"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewCurrencyRate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Ruling"): EventFragment;
}
export interface AcceptedFeeTokenEventObject {
    _token: string;
    _accepted: boolean;
}
export type AcceptedFeeTokenEvent = TypedEvent<[
    string,
    boolean
], AcceptedFeeTokenEventObject>;
export type AcceptedFeeTokenEventFilter = TypedEventFilter<AcceptedFeeTokenEvent>;
export interface DisputeCreationEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type DisputeCreationEvent = TypedEvent<[
    BigNumber,
    string
], DisputeCreationEventObject>;
export type DisputeCreationEventFilter = TypedEventFilter<DisputeCreationEvent>;
export interface NewCurrencyRateEventObject {
    _feeToken: string;
    _rateInEth: BigNumber;
    _rateDecimals: number;
}
export type NewCurrencyRateEvent = TypedEvent<[
    string,
    BigNumber,
    number
], NewCurrencyRateEventObject>;
export type NewCurrencyRateEventFilter = TypedEventFilter<NewCurrencyRateEvent>;
export interface RulingEventObject {
    _arbitrable: string;
    _disputeID: BigNumber;
    _ruling: BigNumber;
}
export type RulingEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], RulingEventObject>;
export type RulingEventFilter = TypedEventFilter<RulingEvent>;
export interface IArbitratorV2 extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IArbitratorV2Interface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            boolean
        ] & {
            ruling: BigNumber;
            tied: boolean;
            overridden: boolean;
        }>;
    };
    "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        boolean,
        boolean
    ] & {
        ruling: BigNumber;
        tied: boolean;
        overridden: boolean;
    }>;
    callStatic: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            boolean
        ] & {
            ruling: BigNumber;
            tied: boolean;
            overridden: boolean;
        }>;
    };
    filters: {
        "AcceptedFeeToken(address,bool)"(_token?: string | null, _accepted?: boolean | null): AcceptedFeeTokenEventFilter;
        AcceptedFeeToken(_token?: string | null, _accepted?: boolean | null): AcceptedFeeTokenEventFilter;
        "DisputeCreation(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
        DisputeCreation(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
        "NewCurrencyRate(address,uint64,uint8)"(_feeToken?: string | null, _rateInEth?: null, _rateDecimals?: null): NewCurrencyRateEventFilter;
        NewCurrencyRate(_feeToken?: string | null, _rateInEth?: null, _rateDecimals?: null): NewCurrencyRateEventFilter;
        "Ruling(address,uint256,uint256)"(_arbitrable?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        Ruling(_arbitrable?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
    };
    estimateGas: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
