import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export interface ISortitionModuleUniversityInterface extends utils.Interface {
    functions: {
        "createDisputeHook(uint256,uint256)": FunctionFragment;
        "createTree(bytes32,bytes)": FunctionFragment;
        "draw(bytes32,uint256,uint256)": FunctionFragment;
        "getJurorBalance(address,uint96)": FunctionFragment;
        "getJurorCourtIDs(address)": FunctionFragment;
        "isJurorStaked(address)": FunctionFragment;
        "lockStake(address,uint256)": FunctionFragment;
        "notifyRandomNumber(uint256)": FunctionFragment;
        "penalizeStake(address,uint256)": FunctionFragment;
        "postDrawHook(uint256,uint256)": FunctionFragment;
        "setJurorInactive(address)": FunctionFragment;
        "setStake(address,uint96,uint256,bool)": FunctionFragment;
        "setTransientJuror(address)": FunctionFragment;
        "unlockStake(address,uint256)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "createDisputeHook" | "createTree" | "draw" | "getJurorBalance" | "getJurorCourtIDs" | "isJurorStaked" | "lockStake" | "notifyRandomNumber" | "penalizeStake" | "postDrawHook" | "setJurorInactive" | "setStake" | "setTransientJuror" | "unlockStake"): FunctionFragment;
    encodeFunctionData(functionFragment: "createDisputeHook", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "createTree", values: [BytesLike, BytesLike]): string;
    encodeFunctionData(functionFragment: "draw", values: [BytesLike, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getJurorBalance", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getJurorCourtIDs", values: [string]): string;
    encodeFunctionData(functionFragment: "isJurorStaked", values: [string]): string;
    encodeFunctionData(functionFragment: "lockStake", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "notifyRandomNumber", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "penalizeStake", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "postDrawHook", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setJurorInactive", values: [string]): string;
    encodeFunctionData(functionFragment: "setStake", values: [string, BigNumberish, BigNumberish, boolean]): string;
    encodeFunctionData(functionFragment: "setTransientJuror", values: [string]): string;
    encodeFunctionData(functionFragment: "unlockStake", values: [string, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "createDisputeHook", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createTree", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "draw", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getJurorBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getJurorCourtIDs", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isJurorStaked", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "lockStake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "notifyRandomNumber", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "penalizeStake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "postDrawHook", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setJurorInactive", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setStake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setTransientJuror", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unlockStake", data: BytesLike): Result;
    events: {
        "NewPhase(uint8)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "NewPhase"): EventFragment;
}
export interface NewPhaseEventObject {
    _phase: number;
}
export type NewPhaseEvent = TypedEvent<[number], NewPhaseEventObject>;
export type NewPhaseEventFilter = TypedEventFilter<NewPhaseEvent>;
export interface ISortitionModuleUniversity extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ISortitionModuleUniversityInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        createDisputeHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        createTree(_key: BytesLike, _extraData: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        draw(_court: BytesLike, _coreDisputeID: BigNumberish, _nonce: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        getJurorBalance(_juror: string, _courtID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            totalStaked: BigNumber;
            totalLocked: BigNumber;
            stakedInCourt: BigNumber;
            nbCourts: BigNumber;
        }>;
        getJurorCourtIDs(_juror: string, overrides?: CallOverrides): Promise<[BigNumber[]]>;
        isJurorStaked(_juror: string, overrides?: CallOverrides): Promise<[boolean]>;
        lockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        notifyRandomNumber(_drawnNumber: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        penalizeStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        postDrawHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        setJurorInactive(_account: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        setStake(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        setTransientJuror(_juror: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        unlockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    createDisputeHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    createTree(_key: BytesLike, _extraData: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    draw(_court: BytesLike, _coreDisputeID: BigNumberish, _nonce: BigNumberish, overrides?: CallOverrides): Promise<string>;
    getJurorBalance(_juror: string, _courtID: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber
    ] & {
        totalStaked: BigNumber;
        totalLocked: BigNumber;
        stakedInCourt: BigNumber;
        nbCourts: BigNumber;
    }>;
    getJurorCourtIDs(_juror: string, overrides?: CallOverrides): Promise<BigNumber[]>;
    isJurorStaked(_juror: string, overrides?: CallOverrides): Promise<boolean>;
    lockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    notifyRandomNumber(_drawnNumber: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    penalizeStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    postDrawHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    setJurorInactive(_account: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    setStake(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    setTransientJuror(_juror: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    unlockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        createDisputeHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: CallOverrides): Promise<void>;
        createTree(_key: BytesLike, _extraData: BytesLike, overrides?: CallOverrides): Promise<void>;
        draw(_court: BytesLike, _coreDisputeID: BigNumberish, _nonce: BigNumberish, overrides?: CallOverrides): Promise<string>;
        getJurorBalance(_juror: string, _courtID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            totalStaked: BigNumber;
            totalLocked: BigNumber;
            stakedInCourt: BigNumber;
            nbCourts: BigNumber;
        }>;
        getJurorCourtIDs(_juror: string, overrides?: CallOverrides): Promise<BigNumber[]>;
        isJurorStaked(_juror: string, overrides?: CallOverrides): Promise<boolean>;
        lockStake(_account: string, _relativeAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        notifyRandomNumber(_drawnNumber: BigNumberish, overrides?: CallOverrides): Promise<void>;
        penalizeStake(_account: string, _relativeAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        postDrawHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setJurorInactive(_account: string, overrides?: CallOverrides): Promise<void>;
        setStake(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber,
            number
        ] & {
            pnkDeposit: BigNumber;
            pnkWithdrawal: BigNumber;
            stakingResult: number;
        }>;
        setTransientJuror(_juror: string, overrides?: CallOverrides): Promise<void>;
        unlockStake(_account: string, _relativeAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "NewPhase(uint8)"(_phase?: null): NewPhaseEventFilter;
        NewPhase(_phase?: null): NewPhaseEventFilter;
    };
    estimateGas: {
        createDisputeHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        createTree(_key: BytesLike, _extraData: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        draw(_court: BytesLike, _coreDisputeID: BigNumberish, _nonce: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getJurorBalance(_juror: string, _courtID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getJurorCourtIDs(_juror: string, overrides?: CallOverrides): Promise<BigNumber>;
        isJurorStaked(_juror: string, overrides?: CallOverrides): Promise<BigNumber>;
        lockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        notifyRandomNumber(_drawnNumber: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        penalizeStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        postDrawHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        setJurorInactive(_account: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        setStake(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        setTransientJuror(_juror: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        unlockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        createDisputeHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        createTree(_key: BytesLike, _extraData: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        draw(_court: BytesLike, _coreDisputeID: BigNumberish, _nonce: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getJurorBalance(_juror: string, _courtID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getJurorCourtIDs(_juror: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isJurorStaked(_juror: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        lockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        notifyRandomNumber(_drawnNumber: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        penalizeStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        postDrawHook(_disputeID: BigNumberish, _roundID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        setJurorInactive(_account: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        setStake(_account: string, _courtID: BigNumberish, _newStake: BigNumberish, _alreadyTransferred: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        setTransientJuror(_juror: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        unlockStake(_account: string, _relativeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
