import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export interface IForeignGatewayInterface extends utils.Interface {
    functions: {
        "arbitrationCost(bytes,address)": FunctionFragment;
        "arbitrationCost(bytes)": FunctionFragment;
        "createDispute(uint256,bytes)": FunctionFragment;
        "createDispute(uint256,bytes,address,uint256)": FunctionFragment;
        "currentRuling(uint256)": FunctionFragment;
        "disputeHashToForeignID(bytes32)": FunctionFragment;
        "homeChainID()": FunctionFragment;
        "homeGateway()": FunctionFragment;
        "relayRule(address,bytes32,uint256,address)": FunctionFragment;
        "senderGateway()": FunctionFragment;
        "veaOutbox()": FunctionFragment;
        "withdrawFees(bytes32)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "arbitrationCost(bytes,address)" | "arbitrationCost(bytes)" | "createDispute(uint256,bytes)" | "createDispute(uint256,bytes,address,uint256)" | "currentRuling" | "disputeHashToForeignID" | "homeChainID" | "homeGateway" | "relayRule" | "senderGateway" | "veaOutbox" | "withdrawFees"): FunctionFragment;
    encodeFunctionData(functionFragment: "arbitrationCost(bytes,address)", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "arbitrationCost(bytes)", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "createDispute(uint256,bytes)", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "createDispute(uint256,bytes,address,uint256)", values: [BigNumberish, BytesLike, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "currentRuling", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "disputeHashToForeignID", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "homeChainID", values?: undefined): string;
    encodeFunctionData(functionFragment: "homeGateway", values?: undefined): string;
    encodeFunctionData(functionFragment: "relayRule", values: [string, BytesLike, BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "senderGateway", values?: undefined): string;
    encodeFunctionData(functionFragment: "veaOutbox", values?: undefined): string;
    encodeFunctionData(functionFragment: "withdrawFees", values: [BytesLike]): string;
    decodeFunctionResult(functionFragment: "arbitrationCost(bytes,address)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "arbitrationCost(bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(uint256,bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute(uint256,bytes,address,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "currentRuling", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputeHashToForeignID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "homeChainID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "homeGateway", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "relayRule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "senderGateway", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "veaOutbox", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdrawFees", data: BytesLike): Result;
    events: {
        "AcceptedFeeToken(address,bool)": EventFragment;
        "CrossChainDisputeOutgoing(bytes32,address,uint256,uint256,bytes)": EventFragment;
        "DisputeCreation(uint256,address)": EventFragment;
        "NewCurrencyRate(address,uint64,uint8)": EventFragment;
        "Ruling(address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AcceptedFeeToken"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "CrossChainDisputeOutgoing"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeCreation"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewCurrencyRate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Ruling"): EventFragment;
}
export interface AcceptedFeeTokenEventObject {
    _token: string;
    _accepted: boolean;
}
export type AcceptedFeeTokenEvent = TypedEvent<[
    string,
    boolean
], AcceptedFeeTokenEventObject>;
export type AcceptedFeeTokenEventFilter = TypedEventFilter<AcceptedFeeTokenEvent>;
export interface CrossChainDisputeOutgoingEventObject {
    _foreignBlockHash: string;
    _foreignArbitrable: string;
    _foreignDisputeID: BigNumber;
    _choices: BigNumber;
    _extraData: string;
}
export type CrossChainDisputeOutgoingEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    BigNumber,
    string
], CrossChainDisputeOutgoingEventObject>;
export type CrossChainDisputeOutgoingEventFilter = TypedEventFilter<CrossChainDisputeOutgoingEvent>;
export interface DisputeCreationEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type DisputeCreationEvent = TypedEvent<[
    BigNumber,
    string
], DisputeCreationEventObject>;
export type DisputeCreationEventFilter = TypedEventFilter<DisputeCreationEvent>;
export interface NewCurrencyRateEventObject {
    _feeToken: string;
    _rateInEth: BigNumber;
    _rateDecimals: number;
}
export type NewCurrencyRateEvent = TypedEvent<[
    string,
    BigNumber,
    number
], NewCurrencyRateEventObject>;
export type NewCurrencyRateEventFilter = TypedEventFilter<NewCurrencyRateEvent>;
export interface RulingEventObject {
    _arbitrable: string;
    _disputeID: BigNumber;
    _ruling: BigNumber;
}
export type RulingEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], RulingEventObject>;
export type RulingEventFilter = TypedEventFilter<RulingEvent>;
export interface IForeignGateway extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IForeignGatewayInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            boolean
        ] & {
            ruling: BigNumber;
            tied: boolean;
            overridden: boolean;
        }>;
        disputeHashToForeignID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<[BigNumber]>;
        homeChainID(overrides?: CallOverrides): Promise<[BigNumber]>;
        homeGateway(overrides?: CallOverrides): Promise<[string]>;
        relayRule(_messageSender: string, _disputeHash: BytesLike, _ruling: BigNumberish, _forwarder: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        senderGateway(overrides?: CallOverrides): Promise<[string]>;
        veaOutbox(overrides?: CallOverrides): Promise<[string]>;
        withdrawFees(_disputeHash: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        boolean,
        boolean
    ] & {
        ruling: BigNumber;
        tied: boolean;
        overridden: boolean;
    }>;
    disputeHashToForeignID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    homeChainID(overrides?: CallOverrides): Promise<BigNumber>;
    homeGateway(overrides?: CallOverrides): Promise<string>;
    relayRule(_messageSender: string, _disputeHash: BytesLike, _ruling: BigNumberish, _forwarder: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    senderGateway(overrides?: CallOverrides): Promise<string>;
    veaOutbox(overrides?: CallOverrides): Promise<string>;
    withdrawFees(_disputeHash: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            boolean
        ] & {
            ruling: BigNumber;
            tied: boolean;
            overridden: boolean;
        }>;
        disputeHashToForeignID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        homeChainID(overrides?: CallOverrides): Promise<BigNumber>;
        homeGateway(overrides?: CallOverrides): Promise<string>;
        relayRule(_messageSender: string, _disputeHash: BytesLike, _ruling: BigNumberish, _forwarder: string, overrides?: CallOverrides): Promise<void>;
        senderGateway(overrides?: CallOverrides): Promise<string>;
        veaOutbox(overrides?: CallOverrides): Promise<string>;
        withdrawFees(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "AcceptedFeeToken(address,bool)"(_token?: string | null, _accepted?: boolean | null): AcceptedFeeTokenEventFilter;
        AcceptedFeeToken(_token?: string | null, _accepted?: boolean | null): AcceptedFeeTokenEventFilter;
        "CrossChainDisputeOutgoing(bytes32,address,uint256,uint256,bytes)"(_foreignBlockHash?: null, _foreignArbitrable?: string | null, _foreignDisputeID?: BigNumberish | null, _choices?: null, _extraData?: null): CrossChainDisputeOutgoingEventFilter;
        CrossChainDisputeOutgoing(_foreignBlockHash?: null, _foreignArbitrable?: string | null, _foreignDisputeID?: BigNumberish | null, _choices?: null, _extraData?: null): CrossChainDisputeOutgoingEventFilter;
        "DisputeCreation(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
        DisputeCreation(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
        "NewCurrencyRate(address,uint64,uint8)"(_feeToken?: string | null, _rateInEth?: null, _rateDecimals?: null): NewCurrencyRateEventFilter;
        NewCurrencyRate(_feeToken?: string | null, _rateInEth?: null, _rateDecimals?: null): NewCurrencyRateEventFilter;
        "Ruling(address,uint256,uint256)"(_arbitrable?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        Ruling(_arbitrable?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
    };
    estimateGas: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        disputeHashToForeignID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        homeChainID(overrides?: CallOverrides): Promise<BigNumber>;
        homeGateway(overrides?: CallOverrides): Promise<BigNumber>;
        relayRule(_messageSender: string, _disputeHash: BytesLike, _ruling: BigNumberish, _forwarder: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        senderGateway(overrides?: CallOverrides): Promise<BigNumber>;
        veaOutbox(overrides?: CallOverrides): Promise<BigNumber>;
        withdrawFees(_disputeHash: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        "arbitrationCost(bytes,address)"(_extraData: BytesLike, _feeToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "arbitrationCost(bytes)"(_extraData: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "createDispute(uint256,bytes)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "createDispute(uint256,bytes,address,uint256)"(_numberOfChoices: BigNumberish, _extraData: BytesLike, _feeToken: string, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        disputeHashToForeignID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        homeChainID(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        homeGateway(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        relayRule(_messageSender: string, _disputeHash: BytesLike, _ruling: BigNumberish, _forwarder: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        senderGateway(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        veaOutbox(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        withdrawFees(_disputeHash: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
