import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export declare namespace IHomeGateway {
    type RelayCreateDisputeParamsStruct = {
        foreignBlockHash: BytesLike;
        foreignChainID: BigNumberish;
        foreignArbitrable: string;
        foreignDisputeID: BigNumberish;
        externalDisputeID: BigNumberish;
        templateId: BigNumberish;
        templateUri: string;
        choices: BigNumberish;
        extraData: BytesLike;
    };
    type RelayCreateDisputeParamsStructOutput = [
        string,
        BigNumber,
        string,
        BigNumber,
        BigNumber,
        BigNumber,
        string,
        BigNumber,
        string
    ] & {
        foreignBlockHash: string;
        foreignChainID: BigNumber;
        foreignArbitrable: string;
        foreignDisputeID: BigNumber;
        externalDisputeID: BigNumber;
        templateId: BigNumber;
        templateUri: string;
        choices: BigNumber;
        extraData: string;
    };
}
export interface IHomeGatewayInterface extends utils.Interface {
    functions: {
        "disputeHashToHomeID(bytes32)": FunctionFragment;
        "feeToken()": FunctionFragment;
        "foreignChainID()": FunctionFragment;
        "foreignGateway()": FunctionFragment;
        "receiverGateway()": FunctionFragment;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)": FunctionFragment;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))": FunctionFragment;
        "rule(uint256,uint256)": FunctionFragment;
        "veaInbox()": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "disputeHashToHomeID" | "feeToken" | "foreignChainID" | "foreignGateway" | "receiverGateway" | "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)" | "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))" | "rule" | "veaInbox"): FunctionFragment;
    encodeFunctionData(functionFragment: "disputeHashToHomeID", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "feeToken", values?: undefined): string;
    encodeFunctionData(functionFragment: "foreignChainID", values?: undefined): string;
    encodeFunctionData(functionFragment: "foreignGateway", values?: undefined): string;
    encodeFunctionData(functionFragment: "receiverGateway", values?: undefined): string;
    encodeFunctionData(functionFragment: "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)", values: [IHomeGateway.RelayCreateDisputeParamsStruct, BigNumberish]): string;
    encodeFunctionData(functionFragment: "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))", values: [IHomeGateway.RelayCreateDisputeParamsStruct]): string;
    encodeFunctionData(functionFragment: "rule", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "veaInbox", values?: undefined): string;
    decodeFunctionResult(functionFragment: "disputeHashToHomeID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "feeToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "foreignChainID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "foreignGateway", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "receiverGateway", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rule", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "veaInbox", data: BytesLike): Result;
    events: {
        "CrossChainDisputeIncoming(address,uint256,address,uint256,uint256,uint256,uint256,string)": EventFragment;
        "DisputeRequest(address,uint256,uint256,uint256,string)": EventFragment;
        "Ruling(address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "CrossChainDisputeIncoming"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeRequest"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Ruling"): EventFragment;
}
export interface CrossChainDisputeIncomingEventObject {
    _arbitrator: string;
    _arbitrableChainId: BigNumber;
    _arbitrable: string;
    _arbitrableDisputeID: BigNumber;
    _arbitratorDisputeID: BigNumber;
    _externalDisputeID: BigNumber;
    _templateId: BigNumber;
    _templateUri: string;
}
export type CrossChainDisputeIncomingEvent = TypedEvent<[
    string,
    BigNumber,
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    string
], CrossChainDisputeIncomingEventObject>;
export type CrossChainDisputeIncomingEventFilter = TypedEventFilter<CrossChainDisputeIncomingEvent>;
export interface DisputeRequestEventObject {
    _arbitrator: string;
    _arbitrableDisputeID: BigNumber;
    _externalDisputeID: BigNumber;
    _templateId: BigNumber;
    _templateUri: string;
}
export type DisputeRequestEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    string
], DisputeRequestEventObject>;
export type DisputeRequestEventFilter = TypedEventFilter<DisputeRequestEvent>;
export interface RulingEventObject {
    _arbitrator: string;
    _disputeID: BigNumber;
    _ruling: BigNumber;
}
export type RulingEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], RulingEventObject>;
export type RulingEventFilter = TypedEventFilter<RulingEvent>;
export interface IHomeGateway extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IHomeGatewayInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        disputeHashToHomeID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<[BigNumber]>;
        feeToken(overrides?: CallOverrides): Promise<[string]>;
        foreignChainID(overrides?: CallOverrides): Promise<[BigNumber]>;
        foreignGateway(overrides?: CallOverrides): Promise<[string]>;
        receiverGateway(overrides?: CallOverrides): Promise<[string]>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        veaInbox(overrides?: CallOverrides): Promise<[string]>;
    };
    disputeHashToHomeID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    feeToken(overrides?: CallOverrides): Promise<string>;
    foreignChainID(overrides?: CallOverrides): Promise<BigNumber>;
    foreignGateway(overrides?: CallOverrides): Promise<string>;
    receiverGateway(overrides?: CallOverrides): Promise<string>;
    "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, _feeAmount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    veaInbox(overrides?: CallOverrides): Promise<string>;
    callStatic: {
        disputeHashToHomeID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        feeToken(overrides?: CallOverrides): Promise<string>;
        foreignChainID(overrides?: CallOverrides): Promise<BigNumber>;
        foreignGateway(overrides?: CallOverrides): Promise<string>;
        receiverGateway(overrides?: CallOverrides): Promise<string>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, _feeAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, overrides?: CallOverrides): Promise<void>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: CallOverrides): Promise<void>;
        veaInbox(overrides?: CallOverrides): Promise<string>;
    };
    filters: {
        "CrossChainDisputeIncoming(address,uint256,address,uint256,uint256,uint256,uint256,string)"(_arbitrator?: null, _arbitrableChainId?: null, _arbitrable?: string | null, _arbitrableDisputeID?: BigNumberish | null, _arbitratorDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): CrossChainDisputeIncomingEventFilter;
        CrossChainDisputeIncoming(_arbitrator?: null, _arbitrableChainId?: null, _arbitrable?: string | null, _arbitrableDisputeID?: BigNumberish | null, _arbitratorDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): CrossChainDisputeIncomingEventFilter;
        "DisputeRequest(address,uint256,uint256,uint256,string)"(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        DisputeRequest(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        "Ruling(address,uint256,uint256)"(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        Ruling(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
    };
    estimateGas: {
        disputeHashToHomeID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        feeToken(overrides?: CallOverrides): Promise<BigNumber>;
        foreignChainID(overrides?: CallOverrides): Promise<BigNumber>;
        foreignGateway(overrides?: CallOverrides): Promise<BigNumber>;
        receiverGateway(overrides?: CallOverrides): Promise<BigNumber>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        veaInbox(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        disputeHashToHomeID(_disputeHash: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        feeToken(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        foreignChainID(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        foreignGateway(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        receiverGateway(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes),uint256)"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, _feeAmount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "relayCreateDispute((bytes32,uint256,address,uint256,uint256,uint256,string,uint256,bytes))"(_params: IHomeGateway.RelayCreateDisputeParamsStruct, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        veaInbox(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
