import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export type ClaimStruct = {
    stateRoot: BytesLike;
    claimer: string;
    timestampClaimed: BigNumberish;
    timestampVerification: BigNumberish;
    blocknumberVerification: BigNumberish;
    honest: BigNumberish;
    challenger: string;
};
export type ClaimStructOutput = [
    string,
    string,
    number,
    number,
    number,
    number,
    string
] & {
    stateRoot: string;
    claimer: string;
    timestampClaimed: number;
    timestampVerification: number;
    blocknumberVerification: number;
    honest: number;
    challenger: string;
};
export interface VeaMockInterface extends utils.Interface {
    functions: {
        "resolveDisputedClaim(uint256,bytes32,(bytes32,address,uint32,uint32,uint32,uint8,address))": FunctionFragment;
        "saveSnapshot()": FunctionFragment;
        "sendMessage(bytes32[],uint64,address,bytes)": FunctionFragment;
        "sendMessage(address,bytes4,bytes)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "resolveDisputedClaim" | "saveSnapshot" | "sendMessage(bytes32[],uint64,address,bytes)" | "sendMessage(address,bytes4,bytes)"): FunctionFragment;
    encodeFunctionData(functionFragment: "resolveDisputedClaim", values: [BigNumberish, BytesLike, ClaimStruct]): string;
    encodeFunctionData(functionFragment: "saveSnapshot", values?: undefined): string;
    encodeFunctionData(functionFragment: "sendMessage(bytes32[],uint64,address,bytes)", values: [BytesLike[], BigNumberish, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "sendMessage(address,bytes4,bytes)", values: [string, BytesLike, BytesLike]): string;
    decodeFunctionResult(functionFragment: "resolveDisputedClaim", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "saveSnapshot", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendMessage(bytes32[],uint64,address,bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sendMessage(address,bytes4,bytes)", data: BytesLike): Result;
    events: {};
}
export interface VeaMock extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: VeaMockInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        resolveDisputedClaim(_epoch: BigNumberish, _stateRoot: BytesLike, _claim: ClaimStruct, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        saveSnapshot(overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "sendMessage(bytes32[],uint64,address,bytes)"(_proof: BytesLike[], _msgId: BigNumberish, _to: string, _message: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "sendMessage(address,bytes4,bytes)"(_to: string, _fnSelector: BytesLike, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    resolveDisputedClaim(_epoch: BigNumberish, _stateRoot: BytesLike, _claim: ClaimStruct, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    saveSnapshot(overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "sendMessage(bytes32[],uint64,address,bytes)"(_proof: BytesLike[], _msgId: BigNumberish, _to: string, _message: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "sendMessage(address,bytes4,bytes)"(_to: string, _fnSelector: BytesLike, _data: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        resolveDisputedClaim(_epoch: BigNumberish, _stateRoot: BytesLike, _claim: ClaimStruct, overrides?: CallOverrides): Promise<void>;
        saveSnapshot(overrides?: CallOverrides): Promise<void>;
        "sendMessage(bytes32[],uint64,address,bytes)"(_proof: BytesLike[], _msgId: BigNumberish, _to: string, _message: BytesLike, overrides?: CallOverrides): Promise<void>;
        "sendMessage(address,bytes4,bytes)"(_to: string, _fnSelector: BytesLike, _data: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {};
    estimateGas: {
        resolveDisputedClaim(_epoch: BigNumberish, _stateRoot: BytesLike, _claim: ClaimStruct, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        saveSnapshot(overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        "sendMessage(bytes32[],uint64,address,bytes)"(_proof: BytesLike[], _msgId: BigNumberish, _to: string, _message: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        "sendMessage(address,bytes4,bytes)"(_to: string, _fnSelector: BytesLike, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        resolveDisputedClaim(_epoch: BigNumberish, _stateRoot: BytesLike, _claim: ClaimStruct, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        saveSnapshot(overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "sendMessage(bytes32[],uint64,address,bytes)"(_proof: BytesLike[], _msgId: BigNumberish, _to: string, _message: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "sendMessage(address,bytes4,bytes)"(_to: string, _fnSelector: BytesLike, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
