import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
export declare namespace IKlerosLiquid {
    type DisputeStruct = {
        subcourtID: BigNumberish;
        arbitrated: string;
        numberOfChoices: BigNumberish;
        period: BigNumberish;
        lastPeriodChange: BigNumberish;
        drawsInRound: BigNumberish;
        commitsInRound: BigNumberish;
        ruled: boolean;
    };
    type DisputeStructOutput = [
        BigNumber,
        string,
        BigNumber,
        number,
        BigNumber,
        BigNumber,
        BigNumber,
        boolean
    ] & {
        subcourtID: BigNumber;
        arbitrated: string;
        numberOfChoices: BigNumber;
        period: number;
        lastPeriodChange: BigNumber;
        drawsInRound: BigNumber;
        commitsInRound: BigNumber;
        ruled: boolean;
    };
    type JurorStruct = {
        stakedTokens: BigNumberish;
        lockedTokens: BigNumberish;
    };
    type JurorStructOutput = [BigNumber, BigNumber] & {
        stakedTokens: BigNumber;
        lockedTokens: BigNumber;
    };
}
export interface IKlerosLiquidInterface extends utils.Interface {
    functions: {
        "appeal(uint256,bytes)": FunctionFragment;
        "appealCost(uint256,bytes)": FunctionFragment;
        "appealPeriod(uint256)": FunctionFragment;
        "arbitrationCost(bytes)": FunctionFragment;
        "changeSubcourtTimesPerPeriod(uint96,uint256[4])": FunctionFragment;
        "courts(uint256)": FunctionFragment;
        "createDispute(uint256,bytes)": FunctionFragment;
        "currentRuling(uint256)": FunctionFragment;
        "disputeStatus(uint256)": FunctionFragment;
        "disputes(uint256)": FunctionFragment;
        "executeGovernorProposal(address,uint256,bytes)": FunctionFragment;
        "getDispute(uint256)": FunctionFragment;
        "getSubcourt(uint96)": FunctionFragment;
        "getVote(uint256,uint256,uint256)": FunctionFragment;
        "jurors(address)": FunctionFragment;
        "lockInsolventTransfers()": FunctionFragment;
        "minStakingTime()": FunctionFragment;
        "phase()": FunctionFragment;
        "pinakion()": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "appeal" | "appealCost" | "appealPeriod" | "arbitrationCost" | "changeSubcourtTimesPerPeriod" | "courts" | "createDispute" | "currentRuling" | "disputeStatus" | "disputes" | "executeGovernorProposal" | "getDispute" | "getSubcourt" | "getVote" | "jurors" | "lockInsolventTransfers" | "minStakingTime" | "phase" | "pinakion"): FunctionFragment;
    encodeFunctionData(functionFragment: "appeal", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "appealCost", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "appealPeriod", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "arbitrationCost", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "changeSubcourtTimesPerPeriod", values: [
        BigNumberish,
        [
            BigNumberish,
            BigNumberish,
            BigNumberish,
            BigNumberish
        ]
    ]): string;
    encodeFunctionData(functionFragment: "courts", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "createDispute", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "currentRuling", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "disputeStatus", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "disputes", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "executeGovernorProposal", values: [string, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "getDispute", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getSubcourt", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getVote", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "jurors", values: [string]): string;
    encodeFunctionData(functionFragment: "lockInsolventTransfers", values?: undefined): string;
    encodeFunctionData(functionFragment: "minStakingTime", values?: undefined): string;
    encodeFunctionData(functionFragment: "phase", values?: undefined): string;
    encodeFunctionData(functionFragment: "pinakion", values?: undefined): string;
    decodeFunctionResult(functionFragment: "appeal", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "appealCost", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "appealPeriod", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "arbitrationCost", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeSubcourtTimesPerPeriod", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "courts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createDispute", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "currentRuling", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputeStatus", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputes", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "executeGovernorProposal", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getDispute", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getSubcourt", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getVote", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "jurors", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "lockInsolventTransfers", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "minStakingTime", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "phase", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pinakion", data: BytesLike): Result;
    events: {
        "AppealDecision(uint256,address)": EventFragment;
        "AppealPossible(uint256,address)": EventFragment;
        "DisputeCreation(uint256,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AppealDecision"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "AppealPossible"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "DisputeCreation"): EventFragment;
}
export interface AppealDecisionEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type AppealDecisionEvent = TypedEvent<[
    BigNumber,
    string
], AppealDecisionEventObject>;
export type AppealDecisionEventFilter = TypedEventFilter<AppealDecisionEvent>;
export interface AppealPossibleEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type AppealPossibleEvent = TypedEvent<[
    BigNumber,
    string
], AppealPossibleEventObject>;
export type AppealPossibleEventFilter = TypedEventFilter<AppealPossibleEvent>;
export interface DisputeCreationEventObject {
    _disputeID: BigNumber;
    _arbitrable: string;
}
export type DisputeCreationEvent = TypedEvent<[
    BigNumber,
    string
], DisputeCreationEventObject>;
export type DisputeCreationEventFilter = TypedEventFilter<DisputeCreationEvent>;
export interface IKlerosLiquid extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IKlerosLiquidInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        appeal(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        appealCost(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber] & {
            start: BigNumber;
            end: BigNumber;
        }>;
        arbitrationCost(_extraData: BytesLike, overrides?: CallOverrides): Promise<[BigNumber] & {
            cost: BigNumber;
        }>;
        changeSubcourtTimesPerPeriod(_subcourtID: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        courts(_index: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            parent: BigNumber;
            hiddenVotes: boolean;
            minStake: BigNumber;
            alpha: BigNumber;
            feeForJuror: BigNumber;
            jurorsForCourtJump: BigNumber;
        }>;
        createDispute(_choices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber] & {
            ruling: BigNumber;
        }>;
        disputeStatus(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[number] & {
            status: number;
        }>;
        disputes(_index: BigNumberish, overrides?: CallOverrides): Promise<[IKlerosLiquid.DisputeStructOutput]>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        getDispute(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[]
        ] & {
            votesLengths: BigNumber[];
            tokensAtStakePerJuror: BigNumber[];
            totalFeesForJurors: BigNumber[];
            votesInEachRound: BigNumber[];
            repartitionsInEachRound: BigNumber[];
            penaltiesInEachRound: BigNumber[];
        }>;
        getSubcourt(_subcourtID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber[],
            [BigNumber, BigNumber, BigNumber, BigNumber]
        ] & {
            children: BigNumber[];
            timesPerPeriod: [BigNumber, BigNumber, BigNumber, BigNumber];
        }>;
        getVote(_disputeID: BigNumberish, _appeal: BigNumberish, _voteID: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            string,
            BigNumber,
            boolean
        ] & {
            account: string;
            commit: string;
            choice: BigNumber;
            voted: boolean;
        }>;
        jurors(_account: string, overrides?: CallOverrides): Promise<[IKlerosLiquid.JurorStructOutput]>;
        lockInsolventTransfers(overrides?: CallOverrides): Promise<[boolean]>;
        minStakingTime(overrides?: CallOverrides): Promise<[BigNumber]>;
        phase(overrides?: CallOverrides): Promise<[number]>;
        pinakion(overrides?: CallOverrides): Promise<[string]>;
    };
    appeal(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    appealCost(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber] & {
        start: BigNumber;
        end: BigNumber;
    }>;
    arbitrationCost(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    changeSubcourtTimesPerPeriod(_subcourtID: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    courts(_index: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        boolean,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber
    ] & {
        parent: BigNumber;
        hiddenVotes: boolean;
        minStake: BigNumber;
        alpha: BigNumber;
        feeForJuror: BigNumber;
        jurorsForCourtJump: BigNumber;
    }>;
    createDispute(_choices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    disputeStatus(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<number>;
    disputes(_index: BigNumberish, overrides?: CallOverrides): Promise<IKlerosLiquid.DisputeStructOutput>;
    executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    getDispute(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber[],
        BigNumber[],
        BigNumber[],
        BigNumber[],
        BigNumber[],
        BigNumber[]
    ] & {
        votesLengths: BigNumber[];
        tokensAtStakePerJuror: BigNumber[];
        totalFeesForJurors: BigNumber[];
        votesInEachRound: BigNumber[];
        repartitionsInEachRound: BigNumber[];
        penaltiesInEachRound: BigNumber[];
    }>;
    getSubcourt(_subcourtID: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber[],
        [BigNumber, BigNumber, BigNumber, BigNumber]
    ] & {
        children: BigNumber[];
        timesPerPeriod: [BigNumber, BigNumber, BigNumber, BigNumber];
    }>;
    getVote(_disputeID: BigNumberish, _appeal: BigNumberish, _voteID: BigNumberish, overrides?: CallOverrides): Promise<[
        string,
        string,
        BigNumber,
        boolean
    ] & {
        account: string;
        commit: string;
        choice: BigNumber;
        voted: boolean;
    }>;
    jurors(_account: string, overrides?: CallOverrides): Promise<IKlerosLiquid.JurorStructOutput>;
    lockInsolventTransfers(overrides?: CallOverrides): Promise<boolean>;
    minStakingTime(overrides?: CallOverrides): Promise<BigNumber>;
    phase(overrides?: CallOverrides): Promise<number>;
    pinakion(overrides?: CallOverrides): Promise<string>;
    callStatic: {
        appeal(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<void>;
        appealCost(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber] & {
            start: BigNumber;
            end: BigNumber;
        }>;
        arbitrationCost(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        changeSubcourtTimesPerPeriod(_subcourtID: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: CallOverrides): Promise<void>;
        courts(_index: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            parent: BigNumber;
            hiddenVotes: boolean;
            minStake: BigNumber;
            alpha: BigNumber;
            feeForJuror: BigNumber;
            jurorsForCourtJump: BigNumber;
        }>;
        createDispute(_choices: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        disputeStatus(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<number>;
        disputes(_index: BigNumberish, overrides?: CallOverrides): Promise<IKlerosLiquid.DisputeStructOutput>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: CallOverrides): Promise<void>;
        getDispute(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[]
        ] & {
            votesLengths: BigNumber[];
            tokensAtStakePerJuror: BigNumber[];
            totalFeesForJurors: BigNumber[];
            votesInEachRound: BigNumber[];
            repartitionsInEachRound: BigNumber[];
            penaltiesInEachRound: BigNumber[];
        }>;
        getSubcourt(_subcourtID: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber[],
            [BigNumber, BigNumber, BigNumber, BigNumber]
        ] & {
            children: BigNumber[];
            timesPerPeriod: [BigNumber, BigNumber, BigNumber, BigNumber];
        }>;
        getVote(_disputeID: BigNumberish, _appeal: BigNumberish, _voteID: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            string,
            BigNumber,
            boolean
        ] & {
            account: string;
            commit: string;
            choice: BigNumber;
            voted: boolean;
        }>;
        jurors(_account: string, overrides?: CallOverrides): Promise<IKlerosLiquid.JurorStructOutput>;
        lockInsolventTransfers(overrides?: CallOverrides): Promise<boolean>;
        minStakingTime(overrides?: CallOverrides): Promise<BigNumber>;
        phase(overrides?: CallOverrides): Promise<number>;
        pinakion(overrides?: CallOverrides): Promise<string>;
    };
    filters: {
        "AppealDecision(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealDecisionEventFilter;
        AppealDecision(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealDecisionEventFilter;
        "AppealPossible(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealPossibleEventFilter;
        AppealPossible(_disputeID?: BigNumberish | null, _arbitrable?: string | null): AppealPossibleEventFilter;
        "DisputeCreation(uint256,address)"(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
        DisputeCreation(_disputeID?: BigNumberish | null, _arbitrable?: string | null): DisputeCreationEventFilter;
    };
    estimateGas: {
        appeal(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        appealCost(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        arbitrationCost(_extraData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        changeSubcourtTimesPerPeriod(_subcourtID: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        courts(_index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        createDispute(_choices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        disputeStatus(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        disputes(_index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        getDispute(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getSubcourt(_subcourtID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getVote(_disputeID: BigNumberish, _appeal: BigNumberish, _voteID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        jurors(_account: string, overrides?: CallOverrides): Promise<BigNumber>;
        lockInsolventTransfers(overrides?: CallOverrides): Promise<BigNumber>;
        minStakingTime(overrides?: CallOverrides): Promise<BigNumber>;
        phase(overrides?: CallOverrides): Promise<BigNumber>;
        pinakion(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        appeal(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        appealCost(_disputeID: BigNumberish, _extraData: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        appealPeriod(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        arbitrationCost(_extraData: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        changeSubcourtTimesPerPeriod(_subcourtID: BigNumberish, _timesPerPeriod: [BigNumberish, BigNumberish, BigNumberish, BigNumberish], overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        courts(_index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        createDispute(_choices: BigNumberish, _extraData: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        currentRuling(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        disputeStatus(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        disputes(_index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        getDispute(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getSubcourt(_subcourtID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getVote(_disputeID: BigNumberish, _appeal: BigNumberish, _voteID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        jurors(_account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        lockInsolventTransfers(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        minStakingTime(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        phase(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        pinakion(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
