import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../../common";
export interface KlerosLiquidToV2GovernorInterface extends utils.Interface {
    functions: {
        "changeGovernor(address)": FunctionFragment;
        "disputes(uint256)": FunctionFragment;
        "executeGovernorProposal(address,uint256,bytes)": FunctionFragment;
        "foreignGateway()": FunctionFragment;
        "frozenTokens(address)": FunctionFragment;
        "governor()": FunctionFragment;
        "isDisputeNotified(uint256,uint256)": FunctionFragment;
        "klerosLiquid()": FunctionFragment;
        "klerosLiquidDisputeIDtoGatewayDisputeID(uint256)": FunctionFragment;
        "notifyFrozenTokens(uint256)": FunctionFragment;
        "onApprove(address,address,uint256)": FunctionFragment;
        "onTransfer(address,address,uint256)": FunctionFragment;
        "proxyPayment(address)": FunctionFragment;
        "relayDispute(uint256)": FunctionFragment;
        "rule(uint256,uint256)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "changeGovernor" | "disputes" | "executeGovernorProposal" | "foreignGateway" | "frozenTokens" | "governor" | "isDisputeNotified" | "klerosLiquid" | "klerosLiquidDisputeIDtoGatewayDisputeID" | "notifyFrozenTokens" | "onApprove" | "onTransfer" | "proxyPayment" | "relayDispute" | "rule"): FunctionFragment;
    encodeFunctionData(functionFragment: "changeGovernor", values: [string]): string;
    encodeFunctionData(functionFragment: "disputes", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "executeGovernorProposal", values: [string, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "foreignGateway", values?: undefined): string;
    encodeFunctionData(functionFragment: "frozenTokens", values: [string]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "isDisputeNotified", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "klerosLiquid", values?: undefined): string;
    encodeFunctionData(functionFragment: "klerosLiquidDisputeIDtoGatewayDisputeID", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "notifyFrozenTokens", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "onApprove", values: [string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "onTransfer", values: [string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "proxyPayment", values: [string]): string;
    encodeFunctionData(functionFragment: "relayDispute", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "rule", values: [BigNumberish, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "changeGovernor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "disputes", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "executeGovernorProposal", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "foreignGateway", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "frozenTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isDisputeNotified", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "klerosLiquid", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "klerosLiquidDisputeIDtoGatewayDisputeID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "notifyFrozenTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "onApprove", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "onTransfer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "proxyPayment", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "relayDispute", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rule", data: BytesLike): Result;
    events: {
        "DisputeRequest(address,uint256,uint256,uint256,string)": EventFragment;
        "Ruling(address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "DisputeRequest"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Ruling"): EventFragment;
}
export interface DisputeRequestEventObject {
    _arbitrator: string;
    _arbitrableDisputeID: BigNumber;
    _externalDisputeID: BigNumber;
    _templateId: BigNumber;
    _templateUri: string;
}
export type DisputeRequestEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    string
], DisputeRequestEventObject>;
export type DisputeRequestEventFilter = TypedEventFilter<DisputeRequestEvent>;
export interface RulingEventObject {
    _arbitrator: string;
    _disputeID: BigNumber;
    _ruling: BigNumber;
}
export type RulingEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], RulingEventObject>;
export type RulingEventFilter = TypedEventFilter<RulingEvent>;
export interface KlerosLiquidToV2Governor extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: KlerosLiquidToV2GovernorInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        disputes(gatewayDisputeId: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean
        ] & {
            klerosLiquidDisputeID: BigNumber;
            ruled: boolean;
        }>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        foreignGateway(overrides?: CallOverrides): Promise<[string]>;
        frozenTokens(account: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            tokenAmount: BigNumber;
        }>;
        governor(overrides?: CallOverrides): Promise<[string]>;
        isDisputeNotified(disputeId: BigNumberish, roundId: BigNumberish, overrides?: CallOverrides): Promise<[boolean]>;
        klerosLiquid(overrides?: CallOverrides): Promise<[string]>;
        klerosLiquidDisputeIDtoGatewayDisputeID(disputeId: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber] & {
            gatewayDisputeId: BigNumber;
        }>;
        notifyFrozenTokens(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        onApprove(arg0: string, arg1: string, arg2: BigNumberish, overrides?: CallOverrides): Promise<[boolean] & {
            allowed: boolean;
        }>;
        onTransfer(_from: string, arg1: string, _amount: BigNumberish, overrides?: CallOverrides): Promise<[boolean] & {
            allowed: boolean;
        }>;
        proxyPayment(arg0: string, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        relayDispute(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    changeGovernor(_governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    disputes(gatewayDisputeId: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        boolean
    ] & {
        klerosLiquidDisputeID: BigNumber;
        ruled: boolean;
    }>;
    executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    foreignGateway(overrides?: CallOverrides): Promise<string>;
    frozenTokens(account: string, overrides?: CallOverrides): Promise<BigNumber>;
    governor(overrides?: CallOverrides): Promise<string>;
    isDisputeNotified(disputeId: BigNumberish, roundId: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    klerosLiquid(overrides?: CallOverrides): Promise<string>;
    klerosLiquidDisputeIDtoGatewayDisputeID(disputeId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    notifyFrozenTokens(_disputeID: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    onApprove(arg0: string, arg1: string, arg2: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    onTransfer(_from: string, arg1: string, _amount: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    proxyPayment(arg0: string, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    relayDispute(_disputeID: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        changeGovernor(_governor: string, overrides?: CallOverrides): Promise<void>;
        disputes(gatewayDisputeId: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean
        ] & {
            klerosLiquidDisputeID: BigNumber;
            ruled: boolean;
        }>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: CallOverrides): Promise<void>;
        foreignGateway(overrides?: CallOverrides): Promise<string>;
        frozenTokens(account: string, overrides?: CallOverrides): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<string>;
        isDisputeNotified(disputeId: BigNumberish, roundId: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        klerosLiquid(overrides?: CallOverrides): Promise<string>;
        klerosLiquidDisputeIDtoGatewayDisputeID(disputeId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        notifyFrozenTokens(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<void>;
        onApprove(arg0: string, arg1: string, arg2: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        onTransfer(_from: string, arg1: string, _amount: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        proxyPayment(arg0: string, overrides?: CallOverrides): Promise<boolean>;
        relayDispute(_disputeID: BigNumberish, overrides?: CallOverrides): Promise<void>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "DisputeRequest(address,uint256,uint256,uint256,string)"(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        DisputeRequest(_arbitrator?: string | null, _arbitrableDisputeID?: BigNumberish | null, _externalDisputeID?: null, _templateId?: null, _templateUri?: null): DisputeRequestEventFilter;
        "Ruling(address,uint256,uint256)"(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
        Ruling(_arbitrator?: string | null, _disputeID?: BigNumberish | null, _ruling?: null): RulingEventFilter;
    };
    estimateGas: {
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        disputes(gatewayDisputeId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        foreignGateway(overrides?: CallOverrides): Promise<BigNumber>;
        frozenTokens(account: string, overrides?: CallOverrides): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<BigNumber>;
        isDisputeNotified(disputeId: BigNumberish, roundId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        klerosLiquid(overrides?: CallOverrides): Promise<BigNumber>;
        klerosLiquidDisputeIDtoGatewayDisputeID(disputeId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        notifyFrozenTokens(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        onApprove(arg0: string, arg1: string, arg2: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        onTransfer(_from: string, arg1: string, _amount: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        proxyPayment(arg0: string, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        relayDispute(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        disputes(gatewayDisputeId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        executeGovernorProposal(_destination: string, _amount: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        foreignGateway(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        frozenTokens(account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isDisputeNotified(disputeId: BigNumberish, roundId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        klerosLiquid(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        klerosLiquidDisputeIDtoGatewayDisputeID(disputeId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        notifyFrozenTokens(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        onApprove(arg0: string, arg1: string, arg2: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        onTransfer(_from: string, arg1: string, _amount: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        proxyPayment(arg0: string, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        relayDispute(_disputeID: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        rule(_disputeID: BigNumberish, _ruling: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
