import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../common";
export interface RandomizerRNGInterface extends utils.Interface {
    functions: {
        "callbackGasLimit()": FunctionFragment;
        "changeGovernor(address)": FunctionFragment;
        "governor()": FunctionFragment;
        "initialize(address,address)": FunctionFragment;
        "proxiableUUID()": FunctionFragment;
        "randomNumbers(uint256)": FunctionFragment;
        "randomizer()": FunctionFragment;
        "randomizerCallback(uint256,bytes32)": FunctionFragment;
        "randomizerWithdraw(uint256)": FunctionFragment;
        "receiveRandomness(uint256)": FunctionFragment;
        "requestRandomness(uint256)": FunctionFragment;
        "requesterToID(address)": FunctionFragment;
        "setCallbackGasLimit(uint256)": FunctionFragment;
        "setRandomizer(address)": FunctionFragment;
        "upgradeToAndCall(address,bytes)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "callbackGasLimit" | "changeGovernor" | "governor" | "initialize" | "proxiableUUID" | "randomNumbers" | "randomizer" | "randomizerCallback" | "randomizerWithdraw" | "receiveRandomness" | "requestRandomness" | "requesterToID" | "setCallbackGasLimit" | "setRandomizer" | "upgradeToAndCall"): FunctionFragment;
    encodeFunctionData(functionFragment: "callbackGasLimit", values?: undefined): string;
    encodeFunctionData(functionFragment: "changeGovernor", values: [string]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "initialize", values: [string, string]): string;
    encodeFunctionData(functionFragment: "proxiableUUID", values?: undefined): string;
    encodeFunctionData(functionFragment: "randomNumbers", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "randomizer", values?: undefined): string;
    encodeFunctionData(functionFragment: "randomizerCallback", values: [BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "randomizerWithdraw", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "receiveRandomness", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "requestRandomness", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "requesterToID", values: [string]): string;
    encodeFunctionData(functionFragment: "setCallbackGasLimit", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRandomizer", values: [string]): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [string, BytesLike]): string;
    decodeFunctionResult(functionFragment: "callbackGasLimit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeGovernor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "proxiableUUID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomNumbers", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomizer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomizerCallback", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "randomizerWithdraw", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "receiveRandomness", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "requestRandomness", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "requesterToID", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCallbackGasLimit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRandomizer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
    events: {
        "Initialized(uint64)": EventFragment;
        "Upgraded(address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Initialized"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
}
export interface InitializedEventObject {
    version: BigNumber;
}
export type InitializedEvent = TypedEvent<[BigNumber], InitializedEventObject>;
export type InitializedEventFilter = TypedEventFilter<InitializedEvent>;
export interface UpgradedEventObject {
    newImplementation: string;
}
export type UpgradedEvent = TypedEvent<[string], UpgradedEventObject>;
export type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export interface RandomizerRNG extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RandomizerRNGInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        callbackGasLimit(overrides?: CallOverrides): Promise<[BigNumber]>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        governor(overrides?: CallOverrides): Promise<[string]>;
        initialize(_randomizer: string, _governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        proxiableUUID(overrides?: CallOverrides): Promise<[string]>;
        randomNumbers(requestId: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber] & {
            number: BigNumber;
        }>;
        randomizer(overrides?: CallOverrides): Promise<[string]>;
        randomizerCallback(_id: BigNumberish, _value: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        randomizerWithdraw(_amount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        receiveRandomness(arg0: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber] & {
            randomNumber: BigNumber;
        }>;
        requestRandomness(arg0: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        requesterToID(requester: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            requestId: BigNumber;
        }>;
        setCallbackGasLimit(_callbackGasLimit: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        setRandomizer(_randomizer: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    callbackGasLimit(overrides?: CallOverrides): Promise<BigNumber>;
    changeGovernor(_governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    governor(overrides?: CallOverrides): Promise<string>;
    initialize(_randomizer: string, _governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    proxiableUUID(overrides?: CallOverrides): Promise<string>;
    randomNumbers(requestId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    randomizer(overrides?: CallOverrides): Promise<string>;
    randomizerCallback(_id: BigNumberish, _value: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    randomizerWithdraw(_amount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    receiveRandomness(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    requestRandomness(arg0: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    requesterToID(requester: string, overrides?: CallOverrides): Promise<BigNumber>;
    setCallbackGasLimit(_callbackGasLimit: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    setRandomizer(_randomizer: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        callbackGasLimit(overrides?: CallOverrides): Promise<BigNumber>;
        changeGovernor(_governor: string, overrides?: CallOverrides): Promise<void>;
        governor(overrides?: CallOverrides): Promise<string>;
        initialize(_randomizer: string, _governor: string, overrides?: CallOverrides): Promise<void>;
        proxiableUUID(overrides?: CallOverrides): Promise<string>;
        randomNumbers(requestId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        randomizer(overrides?: CallOverrides): Promise<string>;
        randomizerCallback(_id: BigNumberish, _value: BytesLike, overrides?: CallOverrides): Promise<void>;
        randomizerWithdraw(_amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        receiveRandomness(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        requestRandomness(arg0: BigNumberish, overrides?: CallOverrides): Promise<void>;
        requesterToID(requester: string, overrides?: CallOverrides): Promise<BigNumber>;
        setCallbackGasLimit(_callbackGasLimit: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setRandomizer(_randomizer: string, overrides?: CallOverrides): Promise<void>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Initialized(uint64)"(version?: null): InitializedEventFilter;
        Initialized(version?: null): InitializedEventFilter;
        "Upgraded(address)"(newImplementation?: string | null): UpgradedEventFilter;
        Upgraded(newImplementation?: string | null): UpgradedEventFilter;
    };
    estimateGas: {
        callbackGasLimit(overrides?: CallOverrides): Promise<BigNumber>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<BigNumber>;
        initialize(_randomizer: string, _governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        proxiableUUID(overrides?: CallOverrides): Promise<BigNumber>;
        randomNumbers(requestId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        randomizer(overrides?: CallOverrides): Promise<BigNumber>;
        randomizerCallback(_id: BigNumberish, _value: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        randomizerWithdraw(_amount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        receiveRandomness(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        requestRandomness(arg0: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        requesterToID(requester: string, overrides?: CallOverrides): Promise<BigNumber>;
        setCallbackGasLimit(_callbackGasLimit: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        setRandomizer(_randomizer: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        callbackGasLimit(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        governor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(_randomizer: string, _governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        proxiableUUID(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        randomNumbers(requestId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        randomizer(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        randomizerCallback(_id: BigNumberish, _value: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        randomizerWithdraw(_amount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        receiveRandomness(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        requestRandomness(arg0: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        requesterToID(requester: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setCallbackGasLimit(_callbackGasLimit: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        setRandomizer(_randomizer: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
