import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../common";
export interface FaucetInterface extends utils.Interface {
    functions: {
        "amount()": FunctionFragment;
        "balance()": FunctionFragment;
        "changeAmount(uint256)": FunctionFragment;
        "changeGovernor(address)": FunctionFragment;
        "governor()": FunctionFragment;
        "request()": FunctionFragment;
        "token()": FunctionFragment;
        "withdraw()": FunctionFragment;
        "withdrewAlready(address)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "amount" | "balance" | "changeAmount" | "changeGovernor" | "governor" | "request" | "token" | "withdraw" | "withdrewAlready"): FunctionFragment;
    encodeFunctionData(functionFragment: "amount", values?: undefined): string;
    encodeFunctionData(functionFragment: "balance", values?: undefined): string;
    encodeFunctionData(functionFragment: "changeAmount", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "changeGovernor", values: [string]): string;
    encodeFunctionData(functionFragment: "governor", values?: undefined): string;
    encodeFunctionData(functionFragment: "request", values?: undefined): string;
    encodeFunctionData(functionFragment: "token", values?: undefined): string;
    encodeFunctionData(functionFragment: "withdraw", values?: undefined): string;
    encodeFunctionData(functionFragment: "withdrewAlready", values: [string]): string;
    decodeFunctionResult(functionFragment: "amount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeAmount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeGovernor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "request", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "token", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdraw", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdrewAlready", data: BytesLike): Result;
    events: {};
}
export interface Faucet extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: FaucetInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        amount(overrides?: CallOverrides): Promise<[BigNumber]>;
        balance(overrides?: CallOverrides): Promise<[BigNumber]>;
        changeAmount(_amount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        governor(overrides?: CallOverrides): Promise<[string]>;
        request(overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        token(overrides?: CallOverrides): Promise<[string]>;
        withdraw(overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        withdrewAlready(arg0: string, overrides?: CallOverrides): Promise<[boolean]>;
    };
    amount(overrides?: CallOverrides): Promise<BigNumber>;
    balance(overrides?: CallOverrides): Promise<BigNumber>;
    changeAmount(_amount: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    changeGovernor(_governor: string, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    governor(overrides?: CallOverrides): Promise<string>;
    request(overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    token(overrides?: CallOverrides): Promise<string>;
    withdraw(overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    withdrewAlready(arg0: string, overrides?: CallOverrides): Promise<boolean>;
    callStatic: {
        amount(overrides?: CallOverrides): Promise<BigNumber>;
        balance(overrides?: CallOverrides): Promise<BigNumber>;
        changeAmount(_amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        changeGovernor(_governor: string, overrides?: CallOverrides): Promise<void>;
        governor(overrides?: CallOverrides): Promise<string>;
        request(overrides?: CallOverrides): Promise<void>;
        token(overrides?: CallOverrides): Promise<string>;
        withdraw(overrides?: CallOverrides): Promise<void>;
        withdrewAlready(arg0: string, overrides?: CallOverrides): Promise<boolean>;
    };
    filters: {};
    estimateGas: {
        amount(overrides?: CallOverrides): Promise<BigNumber>;
        balance(overrides?: CallOverrides): Promise<BigNumber>;
        changeAmount(_amount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        governor(overrides?: CallOverrides): Promise<BigNumber>;
        request(overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        token(overrides?: CallOverrides): Promise<BigNumber>;
        withdraw(overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        withdrewAlready(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        amount(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        balance(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        changeAmount(_amount: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        changeGovernor(_governor: string, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        governor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        request(overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        token(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        withdraw(overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        withdrewAlready(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
