import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../common";
export interface TransactionBatcherInterface extends utils.Interface {
    functions: {
        "batchSend(address[],uint256[],bytes[])": FunctionFragment;
        "batchSendUnchecked(address[],uint256[],bytes[])": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "batchSend" | "batchSendUnchecked"): FunctionFragment;
    encodeFunctionData(functionFragment: "batchSend", values: [string[], BigNumberish[], BytesLike[]]): string;
    encodeFunctionData(functionFragment: "batchSendUnchecked", values: [string[], BigNumberish[], BytesLike[]]): string;
    decodeFunctionResult(functionFragment: "batchSend", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "batchSendUnchecked", data: BytesLike): Result;
    events: {};
}
export interface TransactionBatcher extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: TransactionBatcherInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        batchSend(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        batchSendUnchecked(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
            from?: string;
        }): Promise<ContractTransaction>;
    };
    batchSend(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    batchSendUnchecked(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    callStatic: {
        batchSend(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: CallOverrides): Promise<void>;
        batchSendUnchecked(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: CallOverrides): Promise<void>;
    };
    filters: {};
    estimateGas: {
        batchSend(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
        batchSendUnchecked(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
            from?: string;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        batchSend(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        batchSendUnchecked(targets: string[], values: BigNumberish[], datas: BytesLike[], overrides?: PayableOverrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
    };
}
